/********************************************************************************
** Form generated from reading UI file 'attachmenteditdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ATTACHMENTEDITDIALOG_H
#define UI_ATTACHMENTEDITDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kseparator.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_AttachmentEditDialog
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *mIcon;
    QLineEdit *mLabelEdit;
    KSeparator *kseparator;
    QLabel *mTypeLabel;
    QCheckBox *mInlineCheck;
    QSpacerItem *verticalSpacer;
    QStackedWidget *mStackedWidget;
    QWidget *page;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_2;
    KUrlRequester *mURLRequester;
    QWidget *page_2;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_3;
    QLabel *mSizeLabel;
    QLabel *label;

    void setupUi(QWidget *AttachmentEditDialog)
    {
        if (AttachmentEditDialog->objectName().isEmpty())
            AttachmentEditDialog->setObjectName("AttachmentEditDialog");
        AttachmentEditDialog->resize(446, 241);
        gridLayout = new QGridLayout(AttachmentEditDialog);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        mIcon = new QLabel(AttachmentEditDialog);
        mIcon->setObjectName("mIcon");
        mIcon->setText(QString::fromUtf8("TextLabel"));

        horizontalLayout->addWidget(mIcon);

        mLabelEdit = new QLineEdit(AttachmentEditDialog);
        mLabelEdit->setObjectName("mLabelEdit");
        mLabelEdit->setClearButtonEnabled(true);

        horizontalLayout->addWidget(mLabelEdit);


        gridLayout->addLayout(horizontalLayout, 0, 0, 1, 2);

        kseparator = new KSeparator(AttachmentEditDialog);
        kseparator->setObjectName("kseparator");

        gridLayout->addWidget(kseparator, 1, 0, 1, 2);

        mTypeLabel = new QLabel(AttachmentEditDialog);
        mTypeLabel->setObjectName("mTypeLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(mTypeLabel->sizePolicy().hasHeightForWidth());
        mTypeLabel->setSizePolicy(sizePolicy);

        gridLayout->addWidget(mTypeLabel, 2, 1, 1, 1);

        mInlineCheck = new QCheckBox(AttachmentEditDialog);
        mInlineCheck->setObjectName("mInlineCheck");

        gridLayout->addWidget(mInlineCheck, 4, 0, 1, 2);

        verticalSpacer = new QSpacerItem(434, 109, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 6, 0, 1, 2);

        mStackedWidget = new QStackedWidget(AttachmentEditDialog);
        mStackedWidget->setObjectName("mStackedWidget");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(mStackedWidget->sizePolicy().hasHeightForWidth());
        mStackedWidget->setSizePolicy(sizePolicy1);
        page = new QWidget();
        page->setObjectName("page");
        horizontalLayout_2 = new QHBoxLayout(page);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(0, -1, 0, -1);
        label_2 = new QLabel(page);
        label_2->setObjectName("label_2");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(label_2->sizePolicy().hasHeightForWidth());
        label_2->setSizePolicy(sizePolicy2);
        label_2->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        horizontalLayout_2->addWidget(label_2);

        mURLRequester = new KUrlRequester(page);
        mURLRequester->setObjectName("mURLRequester");

        horizontalLayout_2->addWidget(mURLRequester);

        mStackedWidget->addWidget(page);
        page_2 = new QWidget();
        page_2->setObjectName("page_2");
        horizontalLayout_3 = new QHBoxLayout(page_2);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horizontalLayout_3->setContentsMargins(0, -1, 0, -1);
        label_3 = new QLabel(page_2);
        label_3->setObjectName("label_3");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(label_3->sizePolicy().hasHeightForWidth());
        label_3->setSizePolicy(sizePolicy3);

        horizontalLayout_3->addWidget(label_3);

        mSizeLabel = new QLabel(page_2);
        mSizeLabel->setObjectName("mSizeLabel");

        horizontalLayout_3->addWidget(mSizeLabel);

        mStackedWidget->addWidget(page_2);

        gridLayout->addWidget(mStackedWidget, 3, 0, 1, 2);

        label = new QLabel(AttachmentEditDialog);
        label->setObjectName("label");
        sizePolicy2.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy2);
        label->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label, 2, 0, 1, 1);


        retranslateUi(AttachmentEditDialog);

        mStackedWidget->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(AttachmentEditDialog);
    } // setupUi

    void retranslateUi(QWidget *AttachmentEditDialog)
    {
#if QT_CONFIG(tooltip)
        mLabelEdit->setToolTip(tr2i18n("Give the attachment a name", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mLabelEdit->setWhatsThis(tr2i18n("Type any string you desire here for the name of the attachment", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
        mLabelEdit->setPlaceholderText(tr2i18n("Attachment name", "@label"));
        mTypeLabel->setText(tr2i18n("Unknown", "@label File type of attachment is unknown"));
#if QT_CONFIG(tooltip)
        mInlineCheck->setToolTip(tr2i18n("<html><head/><body><p>Store a copy of the attachment file inside the calendar</p></body></html>", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mInlineCheck->setWhatsThis(tr2i18n("Checking this option will cause the attachment to be stored inside your calendar, which can take a lot of space depending on the size of the attachment. If this option is not checked, then only a link pointing to the attachment will be stored.  Do not use a link for attachments that change often or may be moved (or removed) from their current location.", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
        mInlineCheck->setText(tr2i18n("Store a copy of the attachment in the calendar ", "@option:check"));
        label_2->setText(tr2i18n("Location:", nullptr));
#if QT_CONFIG(tooltip)
        mURLRequester->setToolTip(tr2i18n("Provide a location for the attachment file", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mURLRequester->setWhatsThis(tr2i18n("Enter the path to the attachment file or use the file browser by pressing the adjacent button", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
        label_3->setText(tr2i18n("Size:", "@label"));
        mSizeLabel->setText(tr2i18n("0 KB", nullptr));
        label->setText(tr2i18n("Type:", nullptr));
        (void)AttachmentEditDialog;
    } // retranslateUi

};

namespace Ui {
    class AttachmentEditDialog: public Ui_AttachmentEditDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ATTACHMENTEDITDIALOG_H

