// This file is generated by kconfig_compiler_kf6 from incidenceeditor.kcfg.
// All changes you do to this file will be lost.

#include "globalsettings_incidenceeditor.h"

#include <klocalizedstring.h>

using namespace IncidenceEditorNG;

IncidenceEditorSettingsBase::IncidenceEditorSettingsBase( )
  : KConfigSkeleton( QStringLiteral( "incidenceeditorrc" ) )
{
  setCurrentGroup( QStringLiteral( "AttachmentHandling" ) );

  QList<KConfigSkeleton::ItemEnum::Choice> valuesDefaultEmailAttachMethod;
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Ask");
    choice.label = i18nd("libincidenceeditors6", "Always ask");
    valuesDefaultEmailAttachMethod.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("Link");
    choice.label = i18nd("libincidenceeditors6", "Only attach link to message");
    valuesDefaultEmailAttachMethod.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("InlineFull");
    choice.label = i18nd("libincidenceeditors6", "Attach complete message");
    valuesDefaultEmailAttachMethod.append( choice );
  }
  {
    KConfigSkeleton::ItemEnum::Choice choice;
    choice.name = QStringLiteral("InlineBody");
    choice.label = i18nd("libincidenceeditors6", "Attach message without attachments");
    valuesDefaultEmailAttachMethod.append( choice );
  }
  mDefaultEmailAttachMethodItem = new KConfigSkeleton::ItemEnum( currentGroup(), QStringLiteral( "DefaultEmailAttachMethod" ), mDefaultEmailAttachMethod, valuesDefaultEmailAttachMethod, Ask );
  mDefaultEmailAttachMethodItem->setLabel( i18nd("libincidenceeditors6", "Default Email Attachment Method") );
  mDefaultEmailAttachMethodItem->setToolTip( i18nd("libincidenceeditors6", "Choose the default way of attaching dropped emails to an event") );
  mDefaultEmailAttachMethodItem->setWhatsThis( i18nd("libincidenceeditors6", "The default way of attaching dropped emails to an event") );
  addItem( mDefaultEmailAttachMethodItem, QStringLiteral( "DefaultEmailAttachMethod" ) );
}

IncidenceEditorSettingsBase::~IncidenceEditorSettingsBase()
{
}

