/****************************************************************************
** Meta object code from reading C++ file 'attendeeeditor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../incidenceeditor-26.04.2/src/attendeeeditor.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'attendeeeditor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17IncidenceEditorNG19AttendeeLineFactoryE_t {};
} // unnamed namespace

template <> constexpr inline auto IncidenceEditorNG::AttendeeLineFactory::qt_create_metaobjectdata<qt_meta_tag_ZN17IncidenceEditorNG19AttendeeLineFactoryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "IncidenceEditorNG::AttendeeLineFactory"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AttendeeLineFactory, qt_meta_tag_ZN17IncidenceEditorNG19AttendeeLineFactoryE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject IncidenceEditorNG::AttendeeLineFactory::staticMetaObject = { {
    QMetaObject::SuperData::link<KPIM::MultiplyingLineFactory::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17IncidenceEditorNG19AttendeeLineFactoryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17IncidenceEditorNG19AttendeeLineFactoryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17IncidenceEditorNG19AttendeeLineFactoryE_t>.metaTypes,
    nullptr
} };

void IncidenceEditorNG::AttendeeLineFactory::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AttendeeLineFactory *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *IncidenceEditorNG::AttendeeLineFactory::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *IncidenceEditorNG::AttendeeLineFactory::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17IncidenceEditorNG19AttendeeLineFactoryE_t>.strings))
        return static_cast<void*>(this);
    return KPIM::MultiplyingLineFactory::qt_metacast(_clname);
}

int IncidenceEditorNG::AttendeeLineFactory::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KPIM::MultiplyingLineFactory::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN17IncidenceEditorNG14AttendeeEditorE_t {};
} // unnamed namespace

template <> constexpr inline auto IncidenceEditorNG::AttendeeEditor::qt_create_metaobjectdata<qt_meta_tag_ZN17IncidenceEditorNG14AttendeeEditorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "IncidenceEditorNG::AttendeeEditor",
        "countChanged",
        "",
        "changed",
        "KCalendarCore::Attendee",
        "oldAttendee",
        "newAttendee",
        "editingFinished",
        "KPIM::MultiplyingLine*",
        "slotLineAdded",
        "slotCalculateTotal"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'countChanged'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'changed'
        QtMocHelpers::SignalData<void(const KCalendarCore::Attendee &, const KCalendarCore::Attendee &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 4, 6 },
        }}),
        // Signal 'editingFinished'
        QtMocHelpers::SignalData<void(KPIM::MultiplyingLine *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Slot 'slotLineAdded'
        QtMocHelpers::SlotData<void(KPIM::MultiplyingLine *)>(9, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Slot 'slotCalculateTotal'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AttendeeEditor, qt_meta_tag_ZN17IncidenceEditorNG14AttendeeEditorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject IncidenceEditorNG::AttendeeEditor::staticMetaObject = { {
    QMetaObject::SuperData::link<KPIM::MultiplyingLineEditor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17IncidenceEditorNG14AttendeeEditorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17IncidenceEditorNG14AttendeeEditorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17IncidenceEditorNG14AttendeeEditorE_t>.metaTypes,
    nullptr
} };

void IncidenceEditorNG::AttendeeEditor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AttendeeEditor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->countChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->changed((*reinterpret_cast<std::add_pointer_t<KCalendarCore::Attendee>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KCalendarCore::Attendee>>(_a[2]))); break;
        case 2: _t->editingFinished((*reinterpret_cast<std::add_pointer_t<KPIM::MultiplyingLine*>>(_a[1]))); break;
        case 3: _t->slotLineAdded((*reinterpret_cast<std::add_pointer_t<KPIM::MultiplyingLine*>>(_a[1]))); break;
        case 4: _t->slotCalculateTotal(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KCalendarCore::Attendee >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPIM::MultiplyingLine* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPIM::MultiplyingLine* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AttendeeEditor::*)(int )>(_a, &AttendeeEditor::countChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AttendeeEditor::*)(const KCalendarCore::Attendee & , const KCalendarCore::Attendee & )>(_a, &AttendeeEditor::changed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AttendeeEditor::*)(KPIM::MultiplyingLine * )>(_a, &AttendeeEditor::editingFinished, 2))
            return;
    }
}

const QMetaObject *IncidenceEditorNG::AttendeeEditor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *IncidenceEditorNG::AttendeeEditor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17IncidenceEditorNG14AttendeeEditorE_t>.strings))
        return static_cast<void*>(this);
    return KPIM::MultiplyingLineEditor::qt_metacast(_clname);
}

int IncidenceEditorNG::AttendeeEditor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KPIM::MultiplyingLineEditor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void IncidenceEditorNG::AttendeeEditor::countChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void IncidenceEditorNG::AttendeeEditor::changed(const KCalendarCore::Attendee & _t1, const KCalendarCore::Attendee & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void IncidenceEditorNG::AttendeeEditor::editingFinished(KPIM::MultiplyingLine * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
