/********************************************************************************
** Form generated from reading UI file 'resourcemanagement.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_RESOURCEMANAGEMENT_H
#define UI_RESOURCEMANAGEMENT_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_resourceManagement
{
public:
    QVBoxLayout *verticalLayout_5;
    QSplitter *splitter_2;
    QWidget *layoutWidget;
    QVBoxLayout *verticalLayout;
    QLineEdit *resourceSearch;
    QTreeView *treeResults;
    QSplitter *splitter;
    QWidget *layoutWidget1;
    QVBoxLayout *verticalLayout_3;
    QGroupBox *groupDetails;
    QVBoxLayout *verticalLayout_4;
    QFormLayout *formDetails;
    QGroupBox *groupOwner;
    QVBoxLayout *verticalLayout_2;
    QFormLayout *formOwner;
    QWidget *layoutWidget2;
    QHBoxLayout *resourceCalender;

    void setupUi(QWidget *resourceManagement)
    {
        if (resourceManagement->objectName().isEmpty())
            resourceManagement->setObjectName("resourceManagement");
        resourceManagement->resize(552, 566);
        verticalLayout_5 = new QVBoxLayout(resourceManagement);
        verticalLayout_5->setObjectName("verticalLayout_5");
        verticalLayout_5->setContentsMargins(0, 0, 0, 0);
        splitter_2 = new QSplitter(resourceManagement);
        splitter_2->setObjectName("splitter_2");
        splitter_2->setOrientation(Qt::Horizontal);
        splitter_2->setChildrenCollapsible(false);
        layoutWidget = new QWidget(splitter_2);
        layoutWidget->setObjectName("layoutWidget");
        verticalLayout = new QVBoxLayout(layoutWidget);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        resourceSearch = new QLineEdit(layoutWidget);
        resourceSearch->setObjectName("resourceSearch");
        resourceSearch->setClearButtonEnabled(true);

        verticalLayout->addWidget(resourceSearch);

        treeResults = new QTreeView(layoutWidget);
        treeResults->setObjectName("treeResults");
        treeResults->setAlternatingRowColors(true);
        treeResults->setSelectionBehavior(QAbstractItemView::SelectRows);

        verticalLayout->addWidget(treeResults);

        splitter_2->addWidget(layoutWidget);
        splitter = new QSplitter(splitter_2);
        splitter->setObjectName("splitter");
        splitter->setOrientation(Qt::Vertical);
        splitter->setChildrenCollapsible(false);
        layoutWidget1 = new QWidget(splitter);
        layoutWidget1->setObjectName("layoutWidget1");
        verticalLayout_3 = new QVBoxLayout(layoutWidget1);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        groupDetails = new QGroupBox(layoutWidget1);
        groupDetails->setObjectName("groupDetails");
        groupDetails->setEnabled(true);
        verticalLayout_4 = new QVBoxLayout(groupDetails);
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout_4->setContentsMargins(-1, -1, 4, -1);
        formDetails = new QFormLayout();
        formDetails->setObjectName("formDetails");

        verticalLayout_4->addLayout(formDetails);


        verticalLayout_3->addWidget(groupDetails);

        groupOwner = new QGroupBox(layoutWidget1);
        groupOwner->setObjectName("groupOwner");
        groupOwner->setEnabled(true);
        verticalLayout_2 = new QVBoxLayout(groupOwner);
        verticalLayout_2->setObjectName("verticalLayout_2");
        formOwner = new QFormLayout();
        formOwner->setObjectName("formOwner");

        verticalLayout_2->addLayout(formOwner);


        verticalLayout_3->addWidget(groupOwner);

        splitter->addWidget(layoutWidget1);
        layoutWidget2 = new QWidget(splitter);
        layoutWidget2->setObjectName("layoutWidget2");
        resourceCalender = new QHBoxLayout(layoutWidget2);
        resourceCalender->setObjectName("resourceCalender");
        resourceCalender->setSizeConstraint(QLayout::SetDefaultConstraint);
        resourceCalender->setContentsMargins(0, 0, 0, 0);
        splitter->addWidget(layoutWidget2);
        splitter_2->addWidget(splitter);

        verticalLayout_5->addWidget(splitter_2);


        retranslateUi(resourceManagement);

        QMetaObject::connectSlotsByName(resourceManagement);
    } // setupUi

    void retranslateUi(QWidget *resourceManagement)
    {
#if QT_CONFIG(tooltip)
        resourceSearch->setToolTip(tr2i18n("Enter the search term", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        resourceSearch->setWhatsThis(tr2i18n("Use this text box to enter some keyword for the resource you want to find.", nullptr));
#endif // QT_CONFIG(whatsthis)
        groupDetails->setTitle(tr2i18n("Details", nullptr));
        groupOwner->setTitle(tr2i18n("Owner", nullptr));
        (void)resourceManagement;
    } // retranslateUi

};

namespace Ui {
    class resourceManagement: public Ui_resourceManagement {};
} // namespace Ui

QT_END_NAMESPACE

#endif // RESOURCEMANAGEMENT_H

