/****************************************************************************
** Meta object code from reading C++ file 'attendeeline.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../incidenceeditor-26.04.2/src/attendeeline.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'attendeeline.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17IncidenceEditorNG16AttendeeComboBoxE_t {};
} // unnamed namespace

template <> constexpr inline auto IncidenceEditorNG::AttendeeComboBox::qt_create_metaobjectdata<qt_meta_tag_ZN17IncidenceEditorNG16AttendeeComboBoxE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "IncidenceEditorNG::AttendeeComboBox",
        "rightPressed",
        "",
        "leftPressed",
        "itemChanged",
        "clear",
        "setCurrentIndex",
        "index"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'rightPressed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'leftPressed'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'itemChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clear'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setCurrentIndex'
        QtMocHelpers::SlotData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AttendeeComboBox, qt_meta_tag_ZN17IncidenceEditorNG16AttendeeComboBoxE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject IncidenceEditorNG::AttendeeComboBox::staticMetaObject = { {
    QMetaObject::SuperData::link<QToolButton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17IncidenceEditorNG16AttendeeComboBoxE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17IncidenceEditorNG16AttendeeComboBoxE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17IncidenceEditorNG16AttendeeComboBoxE_t>.metaTypes,
    nullptr
} };

void IncidenceEditorNG::AttendeeComboBox::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AttendeeComboBox *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->rightPressed(); break;
        case 1: _t->leftPressed(); break;
        case 2: _t->itemChanged(); break;
        case 3: _t->clear(); break;
        case 4: _t->setCurrentIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AttendeeComboBox::*)()>(_a, &AttendeeComboBox::rightPressed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AttendeeComboBox::*)()>(_a, &AttendeeComboBox::leftPressed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AttendeeComboBox::*)()>(_a, &AttendeeComboBox::itemChanged, 2))
            return;
    }
}

const QMetaObject *IncidenceEditorNG::AttendeeComboBox::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *IncidenceEditorNG::AttendeeComboBox::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17IncidenceEditorNG16AttendeeComboBoxE_t>.strings))
        return static_cast<void*>(this);
    return QToolButton::qt_metacast(_clname);
}

int IncidenceEditorNG::AttendeeComboBox::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QToolButton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void IncidenceEditorNG::AttendeeComboBox::rightPressed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void IncidenceEditorNG::AttendeeComboBox::leftPressed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void IncidenceEditorNG::AttendeeComboBox::itemChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
namespace {
struct qt_meta_tag_ZN17IncidenceEditorNG16AttendeeLineEditE_t {};
} // unnamed namespace

template <> constexpr inline auto IncidenceEditorNG::AttendeeLineEdit::qt_create_metaobjectdata<qt_meta_tag_ZN17IncidenceEditorNG16AttendeeLineEditE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "IncidenceEditorNG::AttendeeLineEdit",
        "deleteMe",
        "",
        "leftPressed",
        "rightPressed",
        "upPressed",
        "downPressed"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'deleteMe'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'leftPressed'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rightPressed'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'upPressed'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'downPressed'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AttendeeLineEdit, qt_meta_tag_ZN17IncidenceEditorNG16AttendeeLineEditE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject IncidenceEditorNG::AttendeeLineEdit::staticMetaObject = { {
    QMetaObject::SuperData::link<PimCommon::AddresseeLineEdit::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17IncidenceEditorNG16AttendeeLineEditE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17IncidenceEditorNG16AttendeeLineEditE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17IncidenceEditorNG16AttendeeLineEditE_t>.metaTypes,
    nullptr
} };

void IncidenceEditorNG::AttendeeLineEdit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AttendeeLineEdit *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->deleteMe(); break;
        case 1: _t->leftPressed(); break;
        case 2: _t->rightPressed(); break;
        case 3: _t->upPressed(); break;
        case 4: _t->downPressed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AttendeeLineEdit::*)()>(_a, &AttendeeLineEdit::deleteMe, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AttendeeLineEdit::*)()>(_a, &AttendeeLineEdit::leftPressed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AttendeeLineEdit::*)()>(_a, &AttendeeLineEdit::rightPressed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AttendeeLineEdit::*)()>(_a, &AttendeeLineEdit::upPressed, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AttendeeLineEdit::*)()>(_a, &AttendeeLineEdit::downPressed, 4))
            return;
    }
}

const QMetaObject *IncidenceEditorNG::AttendeeLineEdit::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *IncidenceEditorNG::AttendeeLineEdit::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17IncidenceEditorNG16AttendeeLineEditE_t>.strings))
        return static_cast<void*>(this);
    return PimCommon::AddresseeLineEdit::qt_metacast(_clname);
}

int IncidenceEditorNG::AttendeeLineEdit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PimCommon::AddresseeLineEdit::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void IncidenceEditorNG::AttendeeLineEdit::deleteMe()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void IncidenceEditorNG::AttendeeLineEdit::leftPressed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void IncidenceEditorNG::AttendeeLineEdit::rightPressed()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void IncidenceEditorNG::AttendeeLineEdit::upPressed()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void IncidenceEditorNG::AttendeeLineEdit::downPressed()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
namespace {
struct qt_meta_tag_ZN17IncidenceEditorNG12AttendeeLineE_t {};
} // unnamed namespace

template <> constexpr inline auto IncidenceEditorNG::AttendeeLine::qt_create_metaobjectdata<qt_meta_tag_ZN17IncidenceEditorNG12AttendeeLineE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "IncidenceEditorNG::AttendeeLine",
        "changed",
        "",
        "KCalendarCore::Attendee",
        "oldAttendee",
        "newAttendee",
        "editingFinished",
        "KPIM::MultiplyingLine*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'changed'
        QtMocHelpers::SignalData<void(const KCalendarCore::Attendee &, const KCalendarCore::Attendee &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 3, 5 },
        }}),
        // Signal 'editingFinished'
        QtMocHelpers::SignalData<void(KPIM::MultiplyingLine *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AttendeeLine, qt_meta_tag_ZN17IncidenceEditorNG12AttendeeLineE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject IncidenceEditorNG::AttendeeLine::staticMetaObject = { {
    QMetaObject::SuperData::link<KPIM::MultiplyingLine::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17IncidenceEditorNG12AttendeeLineE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17IncidenceEditorNG12AttendeeLineE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17IncidenceEditorNG12AttendeeLineE_t>.metaTypes,
    nullptr
} };

void IncidenceEditorNG::AttendeeLine::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AttendeeLine *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->changed(); break;
        case 1: _t->changed((*reinterpret_cast<std::add_pointer_t<KCalendarCore::Attendee>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KCalendarCore::Attendee>>(_a[2]))); break;
        case 2: _t->editingFinished((*reinterpret_cast<std::add_pointer_t<KPIM::MultiplyingLine*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KCalendarCore::Attendee >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KPIM::MultiplyingLine* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AttendeeLine::*)()>(_a, &AttendeeLine::changed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AttendeeLine::*)(const KCalendarCore::Attendee & , const KCalendarCore::Attendee & )>(_a, &AttendeeLine::changed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AttendeeLine::*)(KPIM::MultiplyingLine * )>(_a, &AttendeeLine::editingFinished, 2))
            return;
    }
}

const QMetaObject *IncidenceEditorNG::AttendeeLine::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *IncidenceEditorNG::AttendeeLine::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17IncidenceEditorNG12AttendeeLineE_t>.strings))
        return static_cast<void*>(this);
    return KPIM::MultiplyingLine::qt_metacast(_clname);
}

int IncidenceEditorNG::AttendeeLine::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KPIM::MultiplyingLine::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void IncidenceEditorNG::AttendeeLine::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void IncidenceEditorNG::AttendeeLine::changed(const KCalendarCore::Attendee & _t1, const KCalendarCore::Attendee & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void IncidenceEditorNG::AttendeeLine::editingFinished(KPIM::MultiplyingLine * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
