/********************************************************************************
** Form generated from reading UI file 'dialogdesktop.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DIALOGDESKTOP_H
#define UI_DIALOGDESKTOP_H

#include <Akonadi/TagWidget>
#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTableView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "CalendarSupport/MessageWidget"
#include "Libkdepim/KCheckComboBox"
#include "kcombobox.h"
#include "kdatecombobox.h"
#include "klineedit.h"
#include "kpimtextedit/richtextcomposerwidget.h"
#include "kseparator.h"
#include "ktimecombobox.h"
#include "ktimezonecombobox.h"
#include "kweekdaycheckcombo.h"

QT_BEGIN_NAMESPACE

class Ui_EventOrTodoDesktop
{
public:
    QVBoxLayout *mainVerticalLayout;
    CalendarSupport::MessageWidget *mMessageWidget;
    QGridLayout *gridLayout;
    QLabel *label;
    QWidget *mCalSelectorPlaceHolder;
    QWidget *mInvitationBar;
    QHBoxLayout *horizontalLayout_10;
    QLabel *label_7;
    QPushButton *mAcceptInvitationButton;
    QPushButton *mDeclineInvitationButton;
    QSpacerItem *horizontalSpacer_13;
    QLabel *label_2;
    QLineEdit *mSummaryEdit;
    QLabel *mLocationLabel;
    QLineEdit *mLocationEdit;
    QFrame *line;
    QLabel *mTaskLabel;
    QWidget *mCompletionPriorityWidget;
    QHBoxLayout *horizontalLayout_8;
    QSlider *mCompletionSlider;
    QLabel *mCompletedLabel;
    QLabel *label_9;
    QComboBox *mPriorityCombo;
    QHBoxLayout *horizontalLayout_5;
    QCheckBox *mWholeDayCheck;
    QSpacerItem *horizontalSpacer_7;
    QCheckBox *mFreeBusyCheck;
    QSpacerItem *horizontalSpacer_12;
    QLabel *mStartLabel;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *mStartCheck;
    KDateComboBox *mStartDateEdit;
    KTimeComboBox *mStartTimeEdit;
    IncidenceEditorNG::KTimeZoneComboBox *mTimeZoneComboStart;
    QLabel *mTimeZoneLabel;
    QSpacerItem *horizontalSpacer_2;
    QLabel *mEndLabel;
    QHBoxLayout *horizontalLayout_4;
    QCheckBox *mEndCheck;
    KDateComboBox *mEndDateEdit;
    KTimeComboBox *mEndTimeEdit;
    IncidenceEditorNG::KTimeZoneComboBox *mTimeZoneComboEnd;
    QSpacerItem *horizontalSpacer;
    QFrame *line_2;
    KSeparator *mTaskSeparator;
    QTabWidget *mTabWidget;
    QWidget *mGeneralTab;
    QGridLayout *gridLayout_9;
    Akonadi::TagWidget *mTagWidget;
    QLabel *mSecrecyLabel;
    QHBoxLayout *horizontalLayout_6;
    QWidget *mEditToolBarPlaceHolder;
    QLabel *mRichTextLabel;
    QSpacerItem *horizontalSpacer_9;
    QLabel *mCategoryLabel;
    QComboBox *mSecrecyCombo;
    KPIMTextEdit::RichTextComposerWidget *mDescriptionEdit;
    QWidget *mAttendeesTab;
    QGridLayout *gridLayout_3;
    QLabel *label_3;
    QStackedWidget *mOrganizerStack;
    QWidget *page;
    QGridLayout *gridLayout_2;
    QComboBox *mOrganizerCombo;
    QWidget *page_2;
    QLabel *mOrganizerLabel;
    QLabel *label_5;
    QHBoxLayout *horizontalLayout_7;
    QLabel *mConflictsLabel;
    QPushButton *mSolveButton;
    QSpacerItem *horizontalSpacer_5;
    QPushButton *mGroupSubstitution;
    QPushButton *mSelectButton;
    QLabel *label_4;
    QHBoxLayout *horizontalLayout_12;
    QCheckBox *mSignItip;
    QCheckBox *mEncryptItip;
    QTableView *mAttendeeTable;
    QWidget *mResourceTab;
    QGridLayout *gridLayout_5;
    QTableView *mResourcesTable;
    QHBoxLayout *horizontalLayout_11;
    KLineEdit *mNewResource;
    QPushButton *mBookResourceButton;
    QSpacerItem *horizontalSpacer_14;
    QPushButton *mFindResourcesButton;
    QWidget *mReminderTab;
    QGridLayout *gridLayout_17;
    QLabel *mQuickAddReminderLabel;
    QComboBox *mAlarmPresetCombo;
    QPushButton *mAlarmAddPresetButton;
    QSpacerItem *horizontalSpacer_3;
    QListWidget *mAlarmList;
    QPushButton *mAlarmNewButton;
    QPushButton *mAlarmConfigureButton;
    QPushButton *mAlarmToggleButton;
    QPushButton *mAlarmRemoveButton;
    QSpacerItem *verticalSpacer;
    QWidget *mRecurrenceTab;
    QGridLayout *gridLayout_19;
    QLabel *mRepeatLabel;
    QHBoxLayout *horizontalLayout_9;
    QComboBox *mRecurrenceTypeCombo;
    QLabel *mFrequencyLabel;
    QSpinBox *mFrequencyEdit;
    QLabel *mRecurrenceRuleLabel;
    QCheckBox *mThisAndFutureCheck;
    QSpacerItem *horizontalSpacer_10;
    QStackedWidget *mRepeatStack;
    QWidget *never_page;
    QWidget *daily_page;
    QGridLayout *gridLayout_11;
    QWidget *weekly_page;
    QGridLayout *gridLayout_4;
    IncidenceEditorNG::KWeekdayCheckCombo *mWeekDayCombo;
    QWidget *Monthly;
    QGridLayout *gridLayout_6;
    QComboBox *mMonthlyCombo;
    QSpacerItem *horizontalSpacer_11;
    QWidget *yearly_page;
    QGridLayout *gridLayout_7;
    QComboBox *mYearlyCombo;
    QSpacerItem *horizontalSpacer_8;
    QLabel *mRecurrenceEndLabel;
    QHBoxLayout *horizontalLayout;
    QComboBox *mRecurrenceEndCombo;
    QStackedWidget *mRecurrenceEndStack;
    QWidget *no_end;
    QGridLayout *gridLayout_16;
    QWidget *end_on;
    QGridLayout *gridLayout_14;
    KDateComboBox *mRecurrenceEndDate;
    QSpacerItem *horizontalSpacer_6;
    QWidget *end_after;
    QGridLayout *gridLayout_10;
    QSpinBox *mEndDurationEdit;
    QLabel *mRecurrenceOccurrencesLabel;
    QLabel *mExceptionsLabel;
    QHBoxLayout *horizontalLayout_3;
    KDateComboBox *mExceptionDateEdit;
    QPushButton *mExceptionAddButton;
    QSpacerItem *horizontalSpacer_4;
    QListWidget *mExceptionList;
    QLabel *mOnLabel;
    QVBoxLayout *verticalLayout;
    QPushButton *mExceptionRemoveButton;
    QSpacerItem *verticalSpacer_5;
    QWidget *mAttachmentsTab;
    QGridLayout *gridLayout_18;
    QWidget *mAttachmentViewPlaceHolder;
    QPushButton *mAddButton;
    QPushButton *mRemoveButton;
    QSpacerItem *verticalSpacer_4;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *EventOrTodoDesktop)
    {
        if (EventOrTodoDesktop->objectName().isEmpty())
            EventOrTodoDesktop->setObjectName("EventOrTodoDesktop");
        EventOrTodoDesktop->resize(1255, 1206);
        mainVerticalLayout = new QVBoxLayout(EventOrTodoDesktop);
        mainVerticalLayout->setObjectName("mainVerticalLayout");
        mMessageWidget = new CalendarSupport::MessageWidget(EventOrTodoDesktop);
        mMessageWidget->setObjectName("mMessageWidget");
        mMessageWidget->setVisible(true);

        mainVerticalLayout->addWidget(mMessageWidget);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        label = new QLabel(EventOrTodoDesktop);
        label->setObjectName("label");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);
        label->setLayoutDirection(Qt::LeftToRight);
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label, 0, 0, 1, 1);

        mCalSelectorPlaceHolder = new QWidget(EventOrTodoDesktop);
        mCalSelectorPlaceHolder->setObjectName("mCalSelectorPlaceHolder");

        gridLayout->addWidget(mCalSelectorPlaceHolder, 0, 1, 1, 1);

        mInvitationBar = new QWidget(EventOrTodoDesktop);
        mInvitationBar->setObjectName("mInvitationBar");
        horizontalLayout_10 = new QHBoxLayout(mInvitationBar);
        horizontalLayout_10->setObjectName("horizontalLayout_10");
        horizontalLayout_10->setContentsMargins(0, 0, 0, 0);
        label_7 = new QLabel(mInvitationBar);
        label_7->setObjectName("label_7");

        horizontalLayout_10->addWidget(label_7);

        mAcceptInvitationButton = new QPushButton(mInvitationBar);
        mAcceptInvitationButton->setObjectName("mAcceptInvitationButton");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("dialog-ok")));
        mAcceptInvitationButton->setIcon(icon);

        horizontalLayout_10->addWidget(mAcceptInvitationButton);

        mDeclineInvitationButton = new QPushButton(mInvitationBar);
        mDeclineInvitationButton->setObjectName("mDeclineInvitationButton");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("dialog-cancel")));
        mDeclineInvitationButton->setIcon(icon1);

        horizontalLayout_10->addWidget(mDeclineInvitationButton);

        horizontalSpacer_13 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_10->addItem(horizontalSpacer_13);


        gridLayout->addWidget(mInvitationBar, 1, 1, 1, 1);

        label_2 = new QLabel(EventOrTodoDesktop);
        label_2->setObjectName("label_2");
        sizePolicy.setHeightForWidth(label_2->sizePolicy().hasHeightForWidth());
        label_2->setSizePolicy(sizePolicy);
        label_2->setLayoutDirection(Qt::LeftToRight);
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_2, 2, 0, 1, 1);

        mSummaryEdit = new QLineEdit(EventOrTodoDesktop);
        mSummaryEdit->setObjectName("mSummaryEdit");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(mSummaryEdit->sizePolicy().hasHeightForWidth());
        mSummaryEdit->setSizePolicy(sizePolicy1);
        mSummaryEdit->setClearButtonEnabled(true);

        gridLayout->addWidget(mSummaryEdit, 2, 1, 1, 1);

        mLocationLabel = new QLabel(EventOrTodoDesktop);
        mLocationLabel->setObjectName("mLocationLabel");
        sizePolicy.setHeightForWidth(mLocationLabel->sizePolicy().hasHeightForWidth());
        mLocationLabel->setSizePolicy(sizePolicy);
        mLocationLabel->setLayoutDirection(Qt::LeftToRight);
        mLocationLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(mLocationLabel, 3, 0, 1, 1);

        mLocationEdit = new QLineEdit(EventOrTodoDesktop);
        mLocationEdit->setObjectName("mLocationEdit");
        sizePolicy1.setHeightForWidth(mLocationEdit->sizePolicy().hasHeightForWidth());
        mLocationEdit->setSizePolicy(sizePolicy1);
        mLocationEdit->setClearButtonEnabled(true);

        gridLayout->addWidget(mLocationEdit, 3, 1, 1, 1);

        line = new QFrame(EventOrTodoDesktop);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line, 4, 0, 1, 2);

        mTaskLabel = new QLabel(EventOrTodoDesktop);
        mTaskLabel->setObjectName("mTaskLabel");
        mTaskLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(mTaskLabel, 5, 0, 1, 1);

        mCompletionPriorityWidget = new QWidget(EventOrTodoDesktop);
        mCompletionPriorityWidget->setObjectName("mCompletionPriorityWidget");
        horizontalLayout_8 = new QHBoxLayout(mCompletionPriorityWidget);
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        horizontalLayout_8->setContentsMargins(0, 0, 0, 0);
        mCompletionSlider = new QSlider(mCompletionPriorityWidget);
        mCompletionSlider->setObjectName("mCompletionSlider");
        mCompletionSlider->setMaximum(100);
        mCompletionSlider->setSingleStep(10);
        mCompletionSlider->setTracking(true);
        mCompletionSlider->setOrientation(Qt::Horizontal);
        mCompletionSlider->setTickPosition(QSlider::TicksBelow);
        mCompletionSlider->setTickInterval(10);

        horizontalLayout_8->addWidget(mCompletionSlider);

        mCompletedLabel = new QLabel(mCompletionPriorityWidget);
        mCompletedLabel->setObjectName("mCompletedLabel");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(mCompletedLabel->sizePolicy().hasHeightForWidth());
        mCompletedLabel->setSizePolicy(sizePolicy2);

        horizontalLayout_8->addWidget(mCompletedLabel);

        label_9 = new QLabel(mCompletionPriorityWidget);
        label_9->setObjectName("label_9");

        horizontalLayout_8->addWidget(label_9);

        mPriorityCombo = new QComboBox(mCompletionPriorityWidget);
        mPriorityCombo->addItem(QString());
        mPriorityCombo->addItem(QString());
        mPriorityCombo->addItem(QString());
        mPriorityCombo->addItem(QString());
        mPriorityCombo->addItem(QString());
        mPriorityCombo->addItem(QString());
        mPriorityCombo->addItem(QString());
        mPriorityCombo->addItem(QString());
        mPriorityCombo->addItem(QString());
        mPriorityCombo->addItem(QString());
        mPriorityCombo->setObjectName("mPriorityCombo");

        horizontalLayout_8->addWidget(mPriorityCombo);


        gridLayout->addWidget(mCompletionPriorityWidget, 5, 1, 1, 1);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        mWholeDayCheck = new QCheckBox(EventOrTodoDesktop);
        mWholeDayCheck->setObjectName("mWholeDayCheck");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(mWholeDayCheck->sizePolicy().hasHeightForWidth());
        mWholeDayCheck->setSizePolicy(sizePolicy3);
        mWholeDayCheck->setChecked(true);

        horizontalLayout_5->addWidget(mWholeDayCheck);

        horizontalSpacer_7 = new QSpacerItem(40, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_7);

        mFreeBusyCheck = new QCheckBox(EventOrTodoDesktop);
        mFreeBusyCheck->setObjectName("mFreeBusyCheck");

        horizontalLayout_5->addWidget(mFreeBusyCheck);

        horizontalSpacer_12 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_12);


        gridLayout->addLayout(horizontalLayout_5, 8, 1, 1, 1);

        mStartLabel = new QLabel(EventOrTodoDesktop);
        mStartLabel->setObjectName("mStartLabel");
        sizePolicy.setHeightForWidth(mStartLabel->sizePolicy().hasHeightForWidth());
        mStartLabel->setSizePolicy(sizePolicy);
        mStartLabel->setLayoutDirection(Qt::LeftToRight);
        mStartLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(mStartLabel, 9, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        mStartCheck = new QCheckBox(EventOrTodoDesktop);
        mStartCheck->setObjectName("mStartCheck");

        horizontalLayout_2->addWidget(mStartCheck);

        mStartDateEdit = new KDateComboBox(EventOrTodoDesktop);
        mStartDateEdit->setObjectName("mStartDateEdit");
        sizePolicy3.setHeightForWidth(mStartDateEdit->sizePolicy().hasHeightForWidth());
        mStartDateEdit->setSizePolicy(sizePolicy3);

        horizontalLayout_2->addWidget(mStartDateEdit);

        mStartTimeEdit = new KTimeComboBox(EventOrTodoDesktop);
        mStartTimeEdit->setObjectName("mStartTimeEdit");
        mStartTimeEdit->setEnabled(false);
        sizePolicy3.setHeightForWidth(mStartTimeEdit->sizePolicy().hasHeightForWidth());
        mStartTimeEdit->setSizePolicy(sizePolicy3);

        horizontalLayout_2->addWidget(mStartTimeEdit);

        mTimeZoneComboStart = new IncidenceEditorNG::KTimeZoneComboBox(EventOrTodoDesktop);
        mTimeZoneComboStart->setObjectName("mTimeZoneComboStart");
        mTimeZoneComboStart->setEnabled(false);
        sizePolicy3.setHeightForWidth(mTimeZoneComboStart->sizePolicy().hasHeightForWidth());
        mTimeZoneComboStart->setSizePolicy(sizePolicy3);

        horizontalLayout_2->addWidget(mTimeZoneComboStart);

        mTimeZoneLabel = new QLabel(EventOrTodoDesktop);
        mTimeZoneLabel->setObjectName("mTimeZoneLabel");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(mTimeZoneLabel->sizePolicy().hasHeightForWidth());
        mTimeZoneLabel->setSizePolicy(sizePolicy4);
        QFont font;
        font.setUnderline(false);
        mTimeZoneLabel->setFont(font);
        mTimeZoneLabel->setTextFormat(Qt::RichText);
        mTimeZoneLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        horizontalLayout_2->addWidget(mTimeZoneLabel);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);


        gridLayout->addLayout(horizontalLayout_2, 9, 1, 1, 1);

        mEndLabel = new QLabel(EventOrTodoDesktop);
        mEndLabel->setObjectName("mEndLabel");
        sizePolicy.setHeightForWidth(mEndLabel->sizePolicy().hasHeightForWidth());
        mEndLabel->setSizePolicy(sizePolicy);
        mEndLabel->setLayoutDirection(Qt::LeftToRight);
        mEndLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(mEndLabel, 10, 0, 1, 1);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        mEndCheck = new QCheckBox(EventOrTodoDesktop);
        mEndCheck->setObjectName("mEndCheck");

        horizontalLayout_4->addWidget(mEndCheck);

        mEndDateEdit = new KDateComboBox(EventOrTodoDesktop);
        mEndDateEdit->setObjectName("mEndDateEdit");
        sizePolicy3.setHeightForWidth(mEndDateEdit->sizePolicy().hasHeightForWidth());
        mEndDateEdit->setSizePolicy(sizePolicy3);

        horizontalLayout_4->addWidget(mEndDateEdit);

        mEndTimeEdit = new KTimeComboBox(EventOrTodoDesktop);
        mEndTimeEdit->setObjectName("mEndTimeEdit");
        mEndTimeEdit->setEnabled(false);
        sizePolicy3.setHeightForWidth(mEndTimeEdit->sizePolicy().hasHeightForWidth());
        mEndTimeEdit->setSizePolicy(sizePolicy3);

        horizontalLayout_4->addWidget(mEndTimeEdit);

        mTimeZoneComboEnd = new IncidenceEditorNG::KTimeZoneComboBox(EventOrTodoDesktop);
        mTimeZoneComboEnd->setObjectName("mTimeZoneComboEnd");
        mTimeZoneComboEnd->setEnabled(false);
        sizePolicy3.setHeightForWidth(mTimeZoneComboEnd->sizePolicy().hasHeightForWidth());
        mTimeZoneComboEnd->setSizePolicy(sizePolicy3);

        horizontalLayout_4->addWidget(mTimeZoneComboEnd);

        horizontalSpacer = new QSpacerItem(40, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer);


        gridLayout->addLayout(horizontalLayout_4, 10, 1, 1, 1);

        line_2 = new QFrame(EventOrTodoDesktop);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line_2, 11, 0, 1, 2);

        mTaskSeparator = new KSeparator(EventOrTodoDesktop);
        mTaskSeparator->setObjectName("mTaskSeparator");

        gridLayout->addWidget(mTaskSeparator, 6, 0, 1, 2);

        mTabWidget = new QTabWidget(EventOrTodoDesktop);
        mTabWidget->setObjectName("mTabWidget");
        mGeneralTab = new QWidget();
        mGeneralTab->setObjectName("mGeneralTab");
        gridLayout_9 = new QGridLayout(mGeneralTab);
        gridLayout_9->setObjectName("gridLayout_9");
        mTagWidget = new Akonadi::TagWidget(mGeneralTab);
        mTagWidget->setObjectName("mTagWidget");

        gridLayout_9->addWidget(mTagWidget, 2, 1, 1, 1);

        mSecrecyLabel = new QLabel(mGeneralTab);
        mSecrecyLabel->setObjectName("mSecrecyLabel");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(mSecrecyLabel->sizePolicy().hasHeightForWidth());
        mSecrecyLabel->setSizePolicy(sizePolicy5);
        mSecrecyLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_9->addWidget(mSecrecyLabel, 2, 2, 1, 1);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        mEditToolBarPlaceHolder = new QWidget(mGeneralTab);
        mEditToolBarPlaceHolder->setObjectName("mEditToolBarPlaceHolder");

        horizontalLayout_6->addWidget(mEditToolBarPlaceHolder);

        mRichTextLabel = new QLabel(mGeneralTab);
        mRichTextLabel->setObjectName("mRichTextLabel");
        sizePolicy5.setHeightForWidth(mRichTextLabel->sizePolicy().hasHeightForWidth());
        mRichTextLabel->setSizePolicy(sizePolicy5);
        mRichTextLabel->setTextFormat(Qt::RichText);

        horizontalLayout_6->addWidget(mRichTextLabel);

        horizontalSpacer_9 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_9);


        gridLayout_9->addLayout(horizontalLayout_6, 0, 0, 1, 4);

        mCategoryLabel = new QLabel(mGeneralTab);
        mCategoryLabel->setObjectName("mCategoryLabel");
        sizePolicy5.setHeightForWidth(mCategoryLabel->sizePolicy().hasHeightForWidth());
        mCategoryLabel->setSizePolicy(sizePolicy5);

        gridLayout_9->addWidget(mCategoryLabel, 2, 0, 1, 1);

        mSecrecyCombo = new QComboBox(mGeneralTab);
        mSecrecyCombo->setObjectName("mSecrecyCombo");

        gridLayout_9->addWidget(mSecrecyCombo, 2, 3, 1, 1);

        mDescriptionEdit = new KPIMTextEdit::RichTextComposerWidget(mGeneralTab);
        mDescriptionEdit->setObjectName("mDescriptionEdit");

        gridLayout_9->addWidget(mDescriptionEdit, 1, 0, 1, 4);

        mTabWidget->addTab(mGeneralTab, QString());
        mAttendeesTab = new QWidget();
        mAttendeesTab->setObjectName("mAttendeesTab");
        gridLayout_3 = new QGridLayout(mAttendeesTab);
        gridLayout_3->setObjectName("gridLayout_3");
        label_3 = new QLabel(mAttendeesTab);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(label_3, 0, 0, 1, 1);

        mOrganizerStack = new QStackedWidget(mAttendeesTab);
        mOrganizerStack->setObjectName("mOrganizerStack");
        QSizePolicy sizePolicy6(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(0);
        sizePolicy6.setHeightForWidth(mOrganizerStack->sizePolicy().hasHeightForWidth());
        mOrganizerStack->setSizePolicy(sizePolicy6);
        page = new QWidget();
        page->setObjectName("page");
        gridLayout_2 = new QGridLayout(page);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(0, 0, 0, 0);
        mOrganizerCombo = new QComboBox(page);
        mOrganizerCombo->setObjectName("mOrganizerCombo");
        sizePolicy1.setHeightForWidth(mOrganizerCombo->sizePolicy().hasHeightForWidth());
        mOrganizerCombo->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(mOrganizerCombo, 0, 0, 1, 1);

        mOrganizerStack->addWidget(page);
        page_2 = new QWidget();
        page_2->setObjectName("page_2");
        mOrganizerLabel = new QLabel(page_2);
        mOrganizerLabel->setObjectName("mOrganizerLabel");
        mOrganizerLabel->setGeometry(QRect(0, 7, 1000, 22));
        sizePolicy6.setHeightForWidth(mOrganizerLabel->sizePolicy().hasHeightForWidth());
        mOrganizerLabel->setSizePolicy(sizePolicy6);
        mOrganizerLabel->setText(QString::fromUtf8("TextLabel"));
        mOrganizerStack->addWidget(page_2);

        gridLayout_3->addWidget(mOrganizerStack, 0, 1, 1, 1);

        label_5 = new QLabel(mAttendeesTab);
        label_5->setObjectName("label_5");
        label_5->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(label_5, 1, 0, 1, 1);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        mConflictsLabel = new QLabel(mAttendeesTab);
        mConflictsLabel->setObjectName("mConflictsLabel");

        horizontalLayout_7->addWidget(mConflictsLabel);

        mSolveButton = new QPushButton(mAttendeesTab);
        mSolveButton->setObjectName("mSolveButton");

        horizontalLayout_7->addWidget(mSolveButton);

        horizontalSpacer_5 = new QSpacerItem(13, 35, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer_5);

        mGroupSubstitution = new QPushButton(mAttendeesTab);
        mGroupSubstitution->setObjectName("mGroupSubstitution");
        mGroupSubstitution->setEnabled(false);

        horizontalLayout_7->addWidget(mGroupSubstitution);

        mSelectButton = new QPushButton(mAttendeesTab);
        mSelectButton->setObjectName("mSelectButton");
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("select")));
        mSelectButton->setIcon(icon2);

        horizontalLayout_7->addWidget(mSelectButton);


        gridLayout_3->addLayout(horizontalLayout_7, 1, 1, 1, 1);

        label_4 = new QLabel(mAttendeesTab);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(label_4, 2, 0, 1, 1);

        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setObjectName("horizontalLayout_12");
        mSignItip = new QCheckBox(mAttendeesTab);
        mSignItip->setObjectName("mSignItip");
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("document-sign")));
        mSignItip->setIcon(icon3);

        horizontalLayout_12->addWidget(mSignItip);

        mEncryptItip = new QCheckBox(mAttendeesTab);
        mEncryptItip->setObjectName("mEncryptItip");
        QIcon icon4(QIcon::fromTheme(QString::fromUtf8("document-encrypt")));
        mEncryptItip->setIcon(icon4);

        horizontalLayout_12->addWidget(mEncryptItip);


        gridLayout_3->addLayout(horizontalLayout_12, 2, 1, 1, 1);

        mAttendeeTable = new QTableView(mAttendeesTab);
        mAttendeeTable->setObjectName("mAttendeeTable");
        mAttendeeTable->setEditTriggers(QAbstractItemView::AllEditTriggers);
        mAttendeeTable->verticalHeader()->setVisible(false);

        gridLayout_3->addWidget(mAttendeeTable, 3, 0, 1, 2);

        mTabWidget->addTab(mAttendeesTab, QString());
        mResourceTab = new QWidget();
        mResourceTab->setObjectName("mResourceTab");
        gridLayout_5 = new QGridLayout(mResourceTab);
        gridLayout_5->setObjectName("gridLayout_5");
        mResourcesTable = new QTableView(mResourceTab);
        mResourcesTable->setObjectName("mResourcesTable");
        mResourcesTable->setEditTriggers(QAbstractItemView::AllEditTriggers);
        mResourcesTable->setShowGrid(true);
        mResourcesTable->setGridStyle(Qt::SolidLine);
        mResourcesTable->setWordWrap(false);
        mResourcesTable->horizontalHeader()->setHighlightSections(false);
        mResourcesTable->verticalHeader()->setVisible(false);

        gridLayout_5->addWidget(mResourcesTable, 0, 0, 1, 1);

        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setObjectName("horizontalLayout_11");
        mNewResource = new KLineEdit(mResourceTab);
        mNewResource->setObjectName("mNewResource");
        mNewResource->setProperty("trapEnterKeyEvent", QVariant(true));
        mNewResource->setProperty("showClearButton", QVariant(true));

        horizontalLayout_11->addWidget(mNewResource);

        mBookResourceButton = new QPushButton(mResourceTab);
        mBookResourceButton->setObjectName("mBookResourceButton");
        mBookResourceButton->setAutoDefault(false);

        horizontalLayout_11->addWidget(mBookResourceButton);

        horizontalSpacer_14 = new QSpacerItem(40, 0, QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);

        horizontalLayout_11->addItem(horizontalSpacer_14);

        mFindResourcesButton = new QPushButton(mResourceTab);
        mFindResourcesButton->setObjectName("mFindResourcesButton");
        QIcon icon5(QIcon::fromTheme(QString::fromUtf8("search")));
        mFindResourcesButton->setIcon(icon5);

        horizontalLayout_11->addWidget(mFindResourcesButton);


        gridLayout_5->addLayout(horizontalLayout_11, 1, 0, 1, 1);

        mTabWidget->addTab(mResourceTab, QString());
        mReminderTab = new QWidget();
        mReminderTab->setObjectName("mReminderTab");
        gridLayout_17 = new QGridLayout(mReminderTab);
        gridLayout_17->setObjectName("gridLayout_17");
        mQuickAddReminderLabel = new QLabel(mReminderTab);
        mQuickAddReminderLabel->setObjectName("mQuickAddReminderLabel");
        sizePolicy5.setHeightForWidth(mQuickAddReminderLabel->sizePolicy().hasHeightForWidth());
        mQuickAddReminderLabel->setSizePolicy(sizePolicy5);

        gridLayout_17->addWidget(mQuickAddReminderLabel, 0, 0, 1, 1);

        mAlarmPresetCombo = new QComboBox(mReminderTab);
        mAlarmPresetCombo->setObjectName("mAlarmPresetCombo");
        sizePolicy3.setHeightForWidth(mAlarmPresetCombo->sizePolicy().hasHeightForWidth());
        mAlarmPresetCombo->setSizePolicy(sizePolicy3);

        gridLayout_17->addWidget(mAlarmPresetCombo, 0, 1, 1, 1);

        mAlarmAddPresetButton = new QPushButton(mReminderTab);
        mAlarmAddPresetButton->setObjectName("mAlarmAddPresetButton");
        sizePolicy3.setHeightForWidth(mAlarmAddPresetButton->sizePolicy().hasHeightForWidth());
        mAlarmAddPresetButton->setSizePolicy(sizePolicy3);
        QIcon icon6(QIcon::fromTheme(QString::fromUtf8("list-add")));
        mAlarmAddPresetButton->setIcon(icon6);

        gridLayout_17->addWidget(mAlarmAddPresetButton, 0, 2, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(141, 22, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_17->addItem(horizontalSpacer_3, 0, 3, 1, 1);

        mAlarmList = new QListWidget(mReminderTab);
        mAlarmList->setObjectName("mAlarmList");
        mAlarmList->setEditTriggers(QAbstractItemView::NoEditTriggers);

        gridLayout_17->addWidget(mAlarmList, 1, 0, 5, 4);

        mAlarmNewButton = new QPushButton(mReminderTab);
        mAlarmNewButton->setObjectName("mAlarmNewButton");
        QIcon icon7(QIcon::fromTheme(QString::fromUtf8("entry-new")));
        mAlarmNewButton->setIcon(icon7);

        gridLayout_17->addWidget(mAlarmNewButton, 1, 4, 1, 1);

        mAlarmConfigureButton = new QPushButton(mReminderTab);
        mAlarmConfigureButton->setObjectName("mAlarmConfigureButton");
        QIcon icon8(QIcon::fromTheme(QString::fromUtf8("entry-edit")));
        mAlarmConfigureButton->setIcon(icon8);

        gridLayout_17->addWidget(mAlarmConfigureButton, 2, 4, 1, 1);

        mAlarmToggleButton = new QPushButton(mReminderTab);
        mAlarmToggleButton->setObjectName("mAlarmToggleButton");

        gridLayout_17->addWidget(mAlarmToggleButton, 3, 4, 1, 1);

        mAlarmRemoveButton = new QPushButton(mReminderTab);
        mAlarmRemoveButton->setObjectName("mAlarmRemoveButton");
        QIcon icon9(QIcon::fromTheme(QString::fromUtf8("list-remove")));
        mAlarmRemoveButton->setIcon(icon9);

        gridLayout_17->addWidget(mAlarmRemoveButton, 4, 4, 1, 1);

        verticalSpacer = new QSpacerItem(88, 126, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_17->addItem(verticalSpacer, 5, 4, 1, 1);

        mTabWidget->addTab(mReminderTab, QString());
        mRecurrenceTab = new QWidget();
        mRecurrenceTab->setObjectName("mRecurrenceTab");
        gridLayout_19 = new QGridLayout(mRecurrenceTab);
        gridLayout_19->setObjectName("gridLayout_19");
        mRepeatLabel = new QLabel(mRecurrenceTab);
        mRepeatLabel->setObjectName("mRepeatLabel");
        sizePolicy.setHeightForWidth(mRepeatLabel->sizePolicy().hasHeightForWidth());
        mRepeatLabel->setSizePolicy(sizePolicy);
        mRepeatLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_19->addWidget(mRepeatLabel, 0, 0, 1, 1);

        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        mRecurrenceTypeCombo = new QComboBox(mRecurrenceTab);
        mRecurrenceTypeCombo->addItem(QString());
        mRecurrenceTypeCombo->addItem(QString());
        mRecurrenceTypeCombo->addItem(QString());
        mRecurrenceTypeCombo->addItem(QString());
        mRecurrenceTypeCombo->addItem(QString());
        mRecurrenceTypeCombo->setObjectName("mRecurrenceTypeCombo");
        sizePolicy3.setHeightForWidth(mRecurrenceTypeCombo->sizePolicy().hasHeightForWidth());
        mRecurrenceTypeCombo->setSizePolicy(sizePolicy3);

        horizontalLayout_9->addWidget(mRecurrenceTypeCombo);

        mFrequencyLabel = new QLabel(mRecurrenceTab);
        mFrequencyLabel->setObjectName("mFrequencyLabel");
        sizePolicy5.setHeightForWidth(mFrequencyLabel->sizePolicy().hasHeightForWidth());
        mFrequencyLabel->setSizePolicy(sizePolicy5);

        horizontalLayout_9->addWidget(mFrequencyLabel);

        mFrequencyEdit = new QSpinBox(mRecurrenceTab);
        mFrequencyEdit->setObjectName("mFrequencyEdit");
        sizePolicy3.setHeightForWidth(mFrequencyEdit->sizePolicy().hasHeightForWidth());
        mFrequencyEdit->setSizePolicy(sizePolicy3);
        mFrequencyEdit->setMinimum(1);
        mFrequencyEdit->setMaximum(999);
        mFrequencyEdit->setValue(1);

        horizontalLayout_9->addWidget(mFrequencyEdit);

        mRecurrenceRuleLabel = new QLabel(mRecurrenceTab);
        mRecurrenceRuleLabel->setObjectName("mRecurrenceRuleLabel");
        sizePolicy.setHeightForWidth(mRecurrenceRuleLabel->sizePolicy().hasHeightForWidth());
        mRecurrenceRuleLabel->setSizePolicy(sizePolicy);

        horizontalLayout_9->addWidget(mRecurrenceRuleLabel);

        mThisAndFutureCheck = new QCheckBox(mRecurrenceTab);
        mThisAndFutureCheck->setObjectName("mThisAndFutureCheck");

        horizontalLayout_9->addWidget(mThisAndFutureCheck);

        horizontalSpacer_10 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_9->addItem(horizontalSpacer_10);


        gridLayout_19->addLayout(horizontalLayout_9, 0, 1, 1, 2);

        mRepeatStack = new QStackedWidget(mRecurrenceTab);
        mRepeatStack->setObjectName("mRepeatStack");
        sizePolicy6.setHeightForWidth(mRepeatStack->sizePolicy().hasHeightForWidth());
        mRepeatStack->setSizePolicy(sizePolicy6);
        never_page = new QWidget();
        never_page->setObjectName("never_page");
        mRepeatStack->addWidget(never_page);
        daily_page = new QWidget();
        daily_page->setObjectName("daily_page");
        gridLayout_11 = new QGridLayout(daily_page);
        gridLayout_11->setObjectName("gridLayout_11");
        gridLayout_11->setContentsMargins(0, 0, 0, 0);
        mRepeatStack->addWidget(daily_page);
        weekly_page = new QWidget();
        weekly_page->setObjectName("weekly_page");
        gridLayout_4 = new QGridLayout(weekly_page);
        gridLayout_4->setObjectName("gridLayout_4");
        gridLayout_4->setContentsMargins(0, 0, 0, 0);
        mWeekDayCombo = new IncidenceEditorNG::KWeekdayCheckCombo(weekly_page);
        mWeekDayCombo->setObjectName("mWeekDayCombo");
        sizePolicy1.setHeightForWidth(mWeekDayCombo->sizePolicy().hasHeightForWidth());
        mWeekDayCombo->setSizePolicy(sizePolicy1);
        mWeekDayCombo->setSizeAdjustPolicy(QComboBox::AdjustToContentsOnFirstShow);

        gridLayout_4->addWidget(mWeekDayCombo, 0, 0, 1, 1);

        mRepeatStack->addWidget(weekly_page);
        Monthly = new QWidget();
        Monthly->setObjectName("Monthly");
        gridLayout_6 = new QGridLayout(Monthly);
        gridLayout_6->setObjectName("gridLayout_6");
        gridLayout_6->setContentsMargins(0, 0, 0, 0);
        mMonthlyCombo = new QComboBox(Monthly);
        mMonthlyCombo->setObjectName("mMonthlyCombo");
        sizePolicy3.setHeightForWidth(mMonthlyCombo->sizePolicy().hasHeightForWidth());
        mMonthlyCombo->setSizePolicy(sizePolicy3);
        mMonthlyCombo->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        gridLayout_6->addWidget(mMonthlyCombo, 0, 0, 1, 1);

        horizontalSpacer_11 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_6->addItem(horizontalSpacer_11, 0, 1, 1, 1);

        mRepeatStack->addWidget(Monthly);
        yearly_page = new QWidget();
        yearly_page->setObjectName("yearly_page");
        gridLayout_7 = new QGridLayout(yearly_page);
        gridLayout_7->setObjectName("gridLayout_7");
        gridLayout_7->setContentsMargins(0, 0, 0, 0);
        mYearlyCombo = new QComboBox(yearly_page);
        mYearlyCombo->setObjectName("mYearlyCombo");
        sizePolicy3.setHeightForWidth(mYearlyCombo->sizePolicy().hasHeightForWidth());
        mYearlyCombo->setSizePolicy(sizePolicy3);
        mYearlyCombo->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        gridLayout_7->addWidget(mYearlyCombo, 0, 0, 1, 1);

        horizontalSpacer_8 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_7->addItem(horizontalSpacer_8, 0, 1, 1, 1);

        mRepeatStack->addWidget(yearly_page);

        gridLayout_19->addWidget(mRepeatStack, 1, 1, 1, 2);

        mRecurrenceEndLabel = new QLabel(mRecurrenceTab);
        mRecurrenceEndLabel->setObjectName("mRecurrenceEndLabel");
        sizePolicy.setHeightForWidth(mRecurrenceEndLabel->sizePolicy().hasHeightForWidth());
        mRecurrenceEndLabel->setSizePolicy(sizePolicy);
        mRecurrenceEndLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_19->addWidget(mRecurrenceEndLabel, 2, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(0);
        horizontalLayout->setObjectName("horizontalLayout");
        mRecurrenceEndCombo = new QComboBox(mRecurrenceTab);
        mRecurrenceEndCombo->addItem(QString());
        mRecurrenceEndCombo->addItem(QString());
        mRecurrenceEndCombo->addItem(QString());
        mRecurrenceEndCombo->setObjectName("mRecurrenceEndCombo");
        sizePolicy3.setHeightForWidth(mRecurrenceEndCombo->sizePolicy().hasHeightForWidth());
        mRecurrenceEndCombo->setSizePolicy(sizePolicy3);

        horizontalLayout->addWidget(mRecurrenceEndCombo);

        mRecurrenceEndStack = new QStackedWidget(mRecurrenceTab);
        mRecurrenceEndStack->setObjectName("mRecurrenceEndStack");
        sizePolicy6.setHeightForWidth(mRecurrenceEndStack->sizePolicy().hasHeightForWidth());
        mRecurrenceEndStack->setSizePolicy(sizePolicy6);
        no_end = new QWidget();
        no_end->setObjectName("no_end");
        gridLayout_16 = new QGridLayout(no_end);
        gridLayout_16->setObjectName("gridLayout_16");
        gridLayout_16->setContentsMargins(0, 0, 0, 0);
        mRecurrenceEndStack->addWidget(no_end);
        end_on = new QWidget();
        end_on->setObjectName("end_on");
        gridLayout_14 = new QGridLayout(end_on);
        gridLayout_14->setObjectName("gridLayout_14");
        gridLayout_14->setContentsMargins(0, 0, 0, 0);
        mRecurrenceEndDate = new KDateComboBox(end_on);
        mRecurrenceEndDate->setObjectName("mRecurrenceEndDate");
        sizePolicy3.setHeightForWidth(mRecurrenceEndDate->sizePolicy().hasHeightForWidth());
        mRecurrenceEndDate->setSizePolicy(sizePolicy3);

        gridLayout_14->addWidget(mRecurrenceEndDate, 0, 0, 1, 1);

        horizontalSpacer_6 = new QSpacerItem(276, 18, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_14->addItem(horizontalSpacer_6, 0, 1, 1, 1);

        mRecurrenceEndStack->addWidget(end_on);
        end_after = new QWidget();
        end_after->setObjectName("end_after");
        gridLayout_10 = new QGridLayout(end_after);
        gridLayout_10->setObjectName("gridLayout_10");
        gridLayout_10->setHorizontalSpacing(0);
        gridLayout_10->setContentsMargins(0, 0, 0, 0);
        mEndDurationEdit = new QSpinBox(end_after);
        mEndDurationEdit->setObjectName("mEndDurationEdit");
        mEndDurationEdit->setMinimum(1);
        mEndDurationEdit->setMaximum(9999);

        gridLayout_10->addWidget(mEndDurationEdit, 0, 0, 1, 1);

        mRecurrenceOccurrencesLabel = new QLabel(end_after);
        mRecurrenceOccurrencesLabel->setObjectName("mRecurrenceOccurrencesLabel");
        sizePolicy2.setHeightForWidth(mRecurrenceOccurrencesLabel->sizePolicy().hasHeightForWidth());
        mRecurrenceOccurrencesLabel->setSizePolicy(sizePolicy2);

        gridLayout_10->addWidget(mRecurrenceOccurrencesLabel, 0, 1, 1, 1);

        mRecurrenceEndStack->addWidget(end_after);

        horizontalLayout->addWidget(mRecurrenceEndStack);


        gridLayout_19->addLayout(horizontalLayout, 2, 1, 1, 2);

        mExceptionsLabel = new QLabel(mRecurrenceTab);
        mExceptionsLabel->setObjectName("mExceptionsLabel");
        sizePolicy.setHeightForWidth(mExceptionsLabel->sizePolicy().hasHeightForWidth());
        mExceptionsLabel->setSizePolicy(sizePolicy);
        mExceptionsLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_19->addWidget(mExceptionsLabel, 3, 0, 2, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        mExceptionDateEdit = new KDateComboBox(mRecurrenceTab);
        mExceptionDateEdit->setObjectName("mExceptionDateEdit");
        sizePolicy3.setHeightForWidth(mExceptionDateEdit->sizePolicy().hasHeightForWidth());
        mExceptionDateEdit->setSizePolicy(sizePolicy3);

        horizontalLayout_3->addWidget(mExceptionDateEdit);

        mExceptionAddButton = new QPushButton(mRecurrenceTab);
        mExceptionAddButton->setObjectName("mExceptionAddButton");
        mExceptionAddButton->setEnabled(false);
        mExceptionAddButton->setIcon(icon6);

        horizontalLayout_3->addWidget(mExceptionAddButton);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_4);


        gridLayout_19->addLayout(horizontalLayout_3, 3, 1, 2, 2);

        mExceptionList = new QListWidget(mRecurrenceTab);
        mExceptionList->setObjectName("mExceptionList");
        QSizePolicy sizePolicy7(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy7.setHorizontalStretch(0);
        sizePolicy7.setVerticalStretch(0);
        sizePolicy7.setHeightForWidth(mExceptionList->sizePolicy().hasHeightForWidth());
        mExceptionList->setSizePolicy(sizePolicy7);
        mExceptionList->setSelectionMode(QAbstractItemView::ExtendedSelection);

        gridLayout_19->addWidget(mExceptionList, 5, 1, 1, 1);

        mOnLabel = new QLabel(mRecurrenceTab);
        mOnLabel->setObjectName("mOnLabel");
        mOnLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_19->addWidget(mOnLabel, 1, 0, 1, 1);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        mExceptionRemoveButton = new QPushButton(mRecurrenceTab);
        mExceptionRemoveButton->setObjectName("mExceptionRemoveButton");
        mExceptionRemoveButton->setEnabled(false);
        mExceptionRemoveButton->setIcon(icon9);

        verticalLayout->addWidget(mExceptionRemoveButton);

        verticalSpacer_5 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_5);


        gridLayout_19->addLayout(verticalLayout, 5, 2, 1, 1);

        gridLayout_19->setColumnStretch(1, 1);
        mTabWidget->addTab(mRecurrenceTab, QString());
        mAttachmentsTab = new QWidget();
        mAttachmentsTab->setObjectName("mAttachmentsTab");
        gridLayout_18 = new QGridLayout(mAttachmentsTab);
        gridLayout_18->setObjectName("gridLayout_18");
        mAttachmentViewPlaceHolder = new QWidget(mAttachmentsTab);
        mAttachmentViewPlaceHolder->setObjectName("mAttachmentViewPlaceHolder");
        QSizePolicy sizePolicy8(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Expanding);
        sizePolicy8.setHorizontalStretch(0);
        sizePolicy8.setVerticalStretch(0);
        sizePolicy8.setHeightForWidth(mAttachmentViewPlaceHolder->sizePolicy().hasHeightForWidth());
        mAttachmentViewPlaceHolder->setSizePolicy(sizePolicy8);

        gridLayout_18->addWidget(mAttachmentViewPlaceHolder, 0, 0, 3, 1);

        mAddButton = new QPushButton(mAttachmentsTab);
        mAddButton->setObjectName("mAddButton");
        QSizePolicy sizePolicy9(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy9.setHorizontalStretch(0);
        sizePolicy9.setVerticalStretch(0);
        sizePolicy9.setHeightForWidth(mAddButton->sizePolicy().hasHeightForWidth());
        mAddButton->setSizePolicy(sizePolicy9);
        mAddButton->setIcon(icon6);

        gridLayout_18->addWidget(mAddButton, 0, 1, 1, 1);

        mRemoveButton = new QPushButton(mAttachmentsTab);
        mRemoveButton->setObjectName("mRemoveButton");
        mRemoveButton->setEnabled(false);
        sizePolicy9.setHeightForWidth(mRemoveButton->sizePolicy().hasHeightForWidth());
        mRemoveButton->setSizePolicy(sizePolicy9);
        mRemoveButton->setIcon(icon9);

        gridLayout_18->addWidget(mRemoveButton, 1, 1, 1, 1);

        verticalSpacer_4 = new QSpacerItem(20, 210, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_18->addItem(verticalSpacer_4, 2, 1, 1, 1);

        mTabWidget->addTab(mAttachmentsTab, QString());

        gridLayout->addWidget(mTabWidget, 12, 0, 1, 2);


        mainVerticalLayout->addLayout(gridLayout);

        buttonBox = new QDialogButtonBox(EventOrTodoDesktop);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::RestoreDefaults);

        mainVerticalLayout->addWidget(buttonBox);

#if QT_CONFIG(shortcut)
        label_2->setBuddy(mSummaryEdit);
        mLocationLabel->setBuddy(mLocationEdit);
        mStartLabel->setBuddy(mStartDateEdit);
        mEndLabel->setBuddy(mEndDateEdit);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(mCalSelectorPlaceHolder, mAcceptInvitationButton);
        QWidget::setTabOrder(mAcceptInvitationButton, mDeclineInvitationButton);
        QWidget::setTabOrder(mDeclineInvitationButton, mSummaryEdit);
        QWidget::setTabOrder(mSummaryEdit, mLocationEdit);
        QWidget::setTabOrder(mLocationEdit, mCompletionSlider);
        QWidget::setTabOrder(mCompletionSlider, mPriorityCombo);
        QWidget::setTabOrder(mPriorityCombo, mWholeDayCheck);
        QWidget::setTabOrder(mWholeDayCheck, mFreeBusyCheck);
        QWidget::setTabOrder(mFreeBusyCheck, mStartCheck);
        QWidget::setTabOrder(mStartCheck, mStartDateEdit);
        QWidget::setTabOrder(mStartDateEdit, mStartTimeEdit);
        QWidget::setTabOrder(mStartTimeEdit, mTimeZoneComboStart);
        QWidget::setTabOrder(mTimeZoneComboStart, mEndCheck);
        QWidget::setTabOrder(mEndCheck, mEndDateEdit);
        QWidget::setTabOrder(mEndDateEdit, mEndTimeEdit);
        QWidget::setTabOrder(mEndTimeEdit, mTimeZoneComboEnd);
        QWidget::setTabOrder(mTimeZoneComboEnd, mTabWidget);
        QWidget::setTabOrder(mTabWidget, mTagWidget);
        QWidget::setTabOrder(mTagWidget, mSecrecyCombo);
        QWidget::setTabOrder(mSecrecyCombo, mSolveButton);
        QWidget::setTabOrder(mSolveButton, mSelectButton);
        QWidget::setTabOrder(mSelectButton, mOrganizerCombo);
        QWidget::setTabOrder(mOrganizerCombo, mAlarmPresetCombo);
        QWidget::setTabOrder(mAlarmPresetCombo, mAlarmAddPresetButton);
        QWidget::setTabOrder(mAlarmAddPresetButton, mAlarmList);
        QWidget::setTabOrder(mAlarmList, mAlarmNewButton);
        QWidget::setTabOrder(mAlarmNewButton, mAlarmConfigureButton);
        QWidget::setTabOrder(mAlarmConfigureButton, mAlarmToggleButton);
        QWidget::setTabOrder(mAlarmToggleButton, mAlarmRemoveButton);
        QWidget::setTabOrder(mAlarmRemoveButton, mRecurrenceTypeCombo);
        QWidget::setTabOrder(mRecurrenceTypeCombo, mFrequencyEdit);
        QWidget::setTabOrder(mFrequencyEdit, mThisAndFutureCheck);
        QWidget::setTabOrder(mThisAndFutureCheck, mWeekDayCombo);
        QWidget::setTabOrder(mWeekDayCombo, mMonthlyCombo);
        QWidget::setTabOrder(mMonthlyCombo, mYearlyCombo);
        QWidget::setTabOrder(mYearlyCombo, mRecurrenceEndCombo);
        QWidget::setTabOrder(mRecurrenceEndCombo, mRecurrenceEndDate);
        QWidget::setTabOrder(mRecurrenceEndDate, mEndDurationEdit);
        QWidget::setTabOrder(mEndDurationEdit, mExceptionDateEdit);
        QWidget::setTabOrder(mExceptionDateEdit, mExceptionAddButton);
        QWidget::setTabOrder(mExceptionAddButton, mExceptionList);
        QWidget::setTabOrder(mExceptionList, mExceptionRemoveButton);
        QWidget::setTabOrder(mExceptionRemoveButton, mAddButton);
        QWidget::setTabOrder(mAddButton, mRemoveButton);

        retranslateUi(EventOrTodoDesktop);
        QObject::connect(mRecurrenceEndCombo, &QComboBox::activated, mRecurrenceEndStack, &QStackedWidget::setCurrentIndex);
        QObject::connect(mRecurrenceTypeCombo, &QComboBox::activated, mRepeatStack, &QStackedWidget::setCurrentIndex);
        QObject::connect(mNewResource, &KLineEdit::returnPressed, mBookResourceButton, qOverload<>(&QPushButton::click));

        mPriorityCombo->setCurrentIndex(5);
        mTabWidget->setCurrentIndex(0);
        mOrganizerStack->setCurrentIndex(0);
        mBookResourceButton->setDefault(false);
        mRepeatStack->setCurrentIndex(2);
        mRecurrenceEndStack->setCurrentIndex(2);


        QMetaObject::connectSlotsByName(EventOrTodoDesktop);
    } // setupUi

    void retranslateUi(QWidget *EventOrTodoDesktop)
    {
#if QT_CONFIG(tooltip)
        mMessageWidget->setToolTip(tr2i18n("A message on this incidence item", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mMessageWidget->setWhatsThis(tr2i18n("Use this message to correct the item parameters.", nullptr));
#endif // QT_CONFIG(whatsthis)
        label->setText(tr2i18n("Calen&dar:", "@label:listbox The calendar to which the todo or event must be added"));
        label_7->setText(tr2i18n("You are Invited, what do you want to do?", "@info"));
#if QT_CONFIG(tooltip)
        mAcceptInvitationButton->setToolTip(tr2i18n("Accept the invitation", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mAcceptInvitationButton->setWhatsThis(tr2i18n("Click this button to accept the invitation.", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
        mAcceptInvitationButton->setText(tr2i18n("Accept", "@action:button Accept an invitation"));
        mDeclineInvitationButton->setText(tr2i18n("Decline", "@action:button decline an invitation"));
#if QT_CONFIG(tooltip)
        label_2->setToolTip(tr2i18n("Set the summary", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        label_2->setWhatsThis(tr2i18n("Sets brief information that will be displayed in many places in the user interface.", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
        label_2->setText(tr2i18n("Summar&y:", "@label"));
#if QT_CONFIG(tooltip)
        mSummaryEdit->setToolTip(tr2i18n("Set the summary", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mSummaryEdit->setWhatsThis(tr2i18n("Sets brief information that will be displayed in many places in the user interface.", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
        mLocationLabel->setText(tr2i18n("&Location:", "@label"));
#if QT_CONFIG(tooltip)
        mLocationEdit->setToolTip(tr2i18n("Set the location", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mLocationEdit->setWhatsThis(tr2i18n("Sets where the event or to-do will take place.", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
        mTaskLabel->setText(tr2i18n("Completion:", "@label line containing to-do specific ui controls"));
        mCompletedLabel->setText(tr2i18n("completed", "@label:slider Showed after the to-do percentage completed slider"));
        label_9->setText(tr2i18n("Priority:", "@label:listbox priority of a to-do"));
        mPriorityCombo->setItemText(0, tr2i18n("unspecified", "@item:inlistbox Priority of a to-do"));
        mPriorityCombo->setItemText(1, tr2i18n("1 (highest)", "@item:inlistbox Priority of a to-do"));
        mPriorityCombo->setItemText(2, tr2i18n("2", "@item:inlistbox Priority of a to-do"));
        mPriorityCombo->setItemText(3, tr2i18n("3", "@item:inlistbox Priority of a to-do"));
        mPriorityCombo->setItemText(4, tr2i18n("4", "@item:inlistbox Priority of a to-do"));
        mPriorityCombo->setItemText(5, tr2i18n("5 (medium)", "@item:inlistbox Priority of a to-do"));
        mPriorityCombo->setItemText(6, tr2i18n("6", "@item:inlistbox Priority of a to-do"));
        mPriorityCombo->setItemText(7, tr2i18n("7", "@item:inlistbox Priority of a to-do"));
        mPriorityCombo->setItemText(8, tr2i18n("8", "@item:inlistbox Priority of a to-do"));
        mPriorityCombo->setItemText(9, tr2i18n("9 (lowest)", "@item:inlistbox Priority of a to-do"));

#if QT_CONFIG(whatsthis)
        mWholeDayCheck->setWhatsThis(tr2i18n("Set if this to-do's start and due dates have times associated with them.", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
        mWholeDayCheck->setText(tr2i18n("All Day", "@option:check"));
        mFreeBusyCheck->setText(tr2i18n("Blocks me for other events", "@option:check"));
        mStartLabel->setText(tr2i18n("S&tart:", "@label Start date/time of the event or todo"));
        mStartCheck->setText(QString());
#if QT_CONFIG(tooltip)
        mStartDateEdit->setToolTip(tr2i18n("Set the start date", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mStartDateEdit->setWhatsThis(tr2i18n("Sets the start date for this to-do", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        mStartTimeEdit->setWhatsThis(tr2i18n("Sets the start time for this to-do.", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        mTimeZoneComboStart->setWhatsThis(tr2i18n("Select the timezone for this event. It will also affect recurrences", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
        mTimeZoneLabel->setText(tr2i18n("<a href=\"hide\">&lt;&lt; Time zones</a>", "@action"));
        mEndLabel->setText(tr2i18n("E&nd:", "@label end date/time for an event or to-do"));
        mEndCheck->setText(QString());
#if QT_CONFIG(whatsthis)
        mEndDateEdit->setWhatsThis(tr2i18n("Sets the due date for this to-do.", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        mEndTimeEdit->setWhatsThis(tr2i18n("Sets the due time for this to-do.", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        mTimeZoneComboEnd->setWhatsThis(tr2i18n("Select the timezone for this event. It will also affect recurrences", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        mSecrecyLabel->setToolTip(tr2i18n("Set the secrecy level", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mSecrecyLabel->setWhatsThis(tr2i18n("Sets whether the access to this event or to-do is restricted. Please note that KOrganizer currently does not use this setting, so the implementation of the restrictions will depend on the groupware server. This means that events or to-dos marked as private or confidential may be visible to others.", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
        mSecrecyLabel->setText(tr2i18n("Access:", "@label:listbox sets the privacy option of the event or to-do"));
        mRichTextLabel->setText(tr2i18n("<a href=\\\"hide\\\">Rich text &gt;&gt;</a>", "@label"));
        mCategoryLabel->setText(tr2i18n("Tags:", "@label"));
#if QT_CONFIG(tooltip)
        mSecrecyCombo->setToolTip(tr2i18n("Set the secrecy level", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mSecrecyCombo->setWhatsThis(tr2i18n("Sets whether the access to this event or to-do is restricted. Please note that KOrganizer currently does not use this setting, so the implementation of the restrictions will depend on the groupware server. This means that events or to-dos marked as private or confidential may be visible to others.", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
        mTabWidget->setTabText(mTabWidget->indexOf(mGeneralTab), tr2i18n("General", "@title:tab General settings for an event or to-do"));
        label_3->setText(tr2i18n("Meeting organizer:", "@label:listbox"));
#if QT_CONFIG(tooltip)
        mOrganizerCombo->setToolTip(tr2i18n("Set the organizer identity", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mOrganizerCombo->setWhatsThis(tr2i18n("Sets the identity corresponding to the organizer of this to-do or event. Identities can be set in the 'Personal' section of the KOrganizer configuration. In addition, identities are gathered from your KMail settings and from your address book.", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
        label_5->setText(tr2i18n("Participants:", "@label participants of this event or to-do"));
        mConflictsLabel->setText(QString());
#if QT_CONFIG(tooltip)
        mSolveButton->setToolTip(tr2i18n("Schedule the meeting with your attendees.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mSolveButton->setWhatsThis(tr2i18n("Opens the scheduling dialog, which will assist in picking a time slot that works for all attendees.", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
        mSolveButton->setText(tr2i18n("Schedule\342\200\246", "@action:button"));
        mGroupSubstitution->setText(tr2i18n("Substitute with group members", nullptr));
#if QT_CONFIG(tooltip)
        mSelectButton->setToolTip(tr2i18n("Select attendees from your address book.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mSelectButton->setWhatsThis(tr2i18n("Opens your address book, allowing you to select new attendees from it.", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
        mSelectButton->setText(tr2i18n("Select Attendees\342\200\246", "@action:button"));
        label_4->setText(tr2i18n("Privacy:", nullptr));
        mSignItip->setText(tr2i18n("Sign Invitation Email", nullptr));
        mEncryptItip->setText(tr2i18n("Encrypt Invitation Email", nullptr));
        mTabWidget->setTabText(mTabWidget->indexOf(mAttendeesTab), tr2i18n("Attendees", "@title:tab attendees of this event or to-do"));
        mBookResourceButton->setText(tr2i18n("Book Resource", nullptr));
        mFindResourcesButton->setText(tr2i18n("Find Resources\342\200\246", nullptr));
        mTabWidget->setTabText(mTabWidget->indexOf(mResourceTab), tr2i18n("Resources", nullptr));
        mQuickAddReminderLabel->setText(tr2i18n("Add default reminder:", "@label"));
        mAlarmAddPresetButton->setText(tr2i18n("Add", "@action:button Adds an reminder"));
        mAlarmNewButton->setText(tr2i18n("New", "@action:button create a new reminder"));
        mAlarmConfigureButton->setText(tr2i18n("Modify", "@action:button modify the selected reminder"));
        mAlarmToggleButton->setText(tr2i18n("Disable", "@action:button disables selected reminder"));
        mAlarmRemoveButton->setText(tr2i18n("Remove", "@action:button removes selected reminders"));
        mTabWidget->setTabText(mTabWidget->indexOf(mReminderTab), tr2i18n("Reminder", "@title:tab Tab to configure reminders for events or to-do"));
        mRepeatLabel->setText(tr2i18n("Repeats:", "@label whether or not this event or to-do repeats"));
        mRecurrenceTypeCombo->setItemText(0, tr2i18n("Never", "@item:inlistbox Lets the user chose how often an event recurs"));
        mRecurrenceTypeCombo->setItemText(1, tr2i18n("Daily", "@item:inlistbox Lets the user chose how often an event recurs"));
        mRecurrenceTypeCombo->setItemText(2, tr2i18n("Weekly", "@item:inlistbox Lets the user chose how often an event recurs"));
        mRecurrenceTypeCombo->setItemText(3, tr2i18n("Monthly", "@item:inlistbox Lets the user chose how often an event recurs"));
        mRecurrenceTypeCombo->setItemText(4, tr2i18n("Yearly", "@item:inlistbox Lets the user chose how often an event recurs"));

        mFrequencyLabel->setText(tr2i18n("every", "@label repeats every [various options]"));
        mRecurrenceRuleLabel->setText(tr2i18n("day(s)", "@label Event or todo recurs every n day(s)"));
        mThisAndFutureCheck->setText(tr2i18n("This and future occurrences.", nullptr));
        mRecurrenceEndLabel->setText(tr2i18n("Ends:", "@label recurrence ends on|after"));
        mRecurrenceEndCombo->setItemText(0, tr2i18n("never", "@item:inlistbox Specifies when a recurring events end"));
        mRecurrenceEndCombo->setItemText(1, tr2i18n("on", "@item:inlistbox Specifies when a recurring events end"));
        mRecurrenceEndCombo->setItemText(2, tr2i18n("after", "@item:inlistbox Specifies when a recurring events end"));

#if QT_CONFIG(whatsthis)
        mRecurrenceEndDate->setWhatsThis(tr2i18n("Date after which the event or to-do should stop recurring", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
        mRecurrenceOccurrencesLabel->setText(tr2i18n("occurrence(s)", "@label"));
        mExceptionsLabel->setText(tr2i18n("Exceptions:", "@label exceptions for the recurrence"));
        mExceptionAddButton->setText(tr2i18n("Add", "@action:button adds an exception on the recurrence"));
        mOnLabel->setText(tr2i18n("on:", "@label The event ends on [different options]"));
        mExceptionRemoveButton->setText(tr2i18n("Remove", "@action:button removes an exception"));
        mTabWidget->setTabText(mTabWidget->indexOf(mRecurrenceTab), tr2i18n("Recurrence", "@title:tab"));
#if QT_CONFIG(tooltip)
        mAddButton->setToolTip(tr2i18n("Add an attachment", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mAddButton->setWhatsThis(tr2i18n("Shows a dialog used to select an attachment to add to this event or to-do as link or as inline data.", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
        mAddButton->setText(tr2i18n("Add", "@action:button adds an attachment"));
#if QT_CONFIG(tooltip)
        mRemoveButton->setToolTip(tr2i18n("Remove the selected attachment", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mRemoveButton->setWhatsThis(tr2i18n("Removes the attachment selected in the list above from this event or to-do.", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
        mRemoveButton->setText(tr2i18n("Remove", "@action:button remove an attachment"));
        mTabWidget->setTabText(mTabWidget->indexOf(mAttachmentsTab), tr2i18n("Attachments", "@title:tab configure attachments of an event or todo"));
        (void)EventOrTodoDesktop;
    } // retranslateUi

};

namespace Ui {
    class EventOrTodoDesktop: public Ui_EventOrTodoDesktop {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DIALOGDESKTOP_H

