/********************************************************************************
** Form generated from reading UI file 'alarmdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ALARMDIALOG_H
#define UI_ALARMDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"
#include "ktextedit.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_AlarmDialog
{
public:
    QGridLayout *gridLayout;
    QLabel *label;
    QHBoxLayout *horizontalLayout;
    QSpinBox *mAlarmOffset;
    QComboBox *mOffsetUnit;
    QComboBox *mBeforeAfter;
    QLabel *label_2;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *mRepeats;
    QSpinBox *mRepeatCount;
    QSpinBox *mRepeatInterval;
    QLabel *label_3;
    QComboBox *mTypeCombo;
    QStackedWidget *mTypeStack;
    QWidget *DisplayStack;
    QVBoxLayout *vboxLayout;
    KTextEdit *mDisplayText;
    QWidget *AudioStack;
    QGridLayout *gridLayout_2;
    QLabel *mSoundFileLabel;
    KUrlRequester *mSoundFile;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *AlarmDialog)
    {
        if (AlarmDialog->objectName().isEmpty())
            AlarmDialog->setObjectName("AlarmDialog");
        AlarmDialog->resize(439, 315);
        gridLayout = new QGridLayout(AlarmDialog);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        label = new QLabel(AlarmDialog);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        mAlarmOffset = new QSpinBox(AlarmDialog);
        mAlarmOffset->setObjectName("mAlarmOffset");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(mAlarmOffset->sizePolicy().hasHeightForWidth());
        mAlarmOffset->setSizePolicy(sizePolicy);
        mAlarmOffset->setMinimum(0);
        mAlarmOffset->setMaximum(99999);
        mAlarmOffset->setValue(15);

        horizontalLayout->addWidget(mAlarmOffset);

        mOffsetUnit = new QComboBox(AlarmDialog);
        mOffsetUnit->addItem(QString());
        mOffsetUnit->addItem(QString());
        mOffsetUnit->addItem(QString());
        mOffsetUnit->setObjectName("mOffsetUnit");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(mOffsetUnit->sizePolicy().hasHeightForWidth());
        mOffsetUnit->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(mOffsetUnit);

        mBeforeAfter = new QComboBox(AlarmDialog);
        mBeforeAfter->addItem(QString());
        mBeforeAfter->addItem(QString());
        mBeforeAfter->addItem(QString());
        mBeforeAfter->addItem(QString());
        mBeforeAfter->setObjectName("mBeforeAfter");

        horizontalLayout->addWidget(mBeforeAfter);


        gridLayout->addLayout(horizontalLayout, 0, 1, 1, 1);

        label_2 = new QLabel(AlarmDialog);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        mRepeats = new QCheckBox(AlarmDialog);
        mRepeats->setObjectName("mRepeats");
        sizePolicy.setHeightForWidth(mRepeats->sizePolicy().hasHeightForWidth());
        mRepeats->setSizePolicy(sizePolicy);

        horizontalLayout_2->addWidget(mRepeats);

        mRepeatCount = new QSpinBox(AlarmDialog);
        mRepeatCount->setObjectName("mRepeatCount");
        mRepeatCount->setEnabled(false);
        mRepeatCount->setMinimum(1);
        mRepeatCount->setMaximum(500);

        horizontalLayout_2->addWidget(mRepeatCount);

        mRepeatInterval = new QSpinBox(AlarmDialog);
        mRepeatInterval->setObjectName("mRepeatInterval");
        mRepeatInterval->setEnabled(false);
        mRepeatInterval->setMinimum(1);
        mRepeatInterval->setMaximum(999);

        horizontalLayout_2->addWidget(mRepeatInterval);


        gridLayout->addLayout(horizontalLayout_2, 1, 1, 1, 1);

        label_3 = new QLabel(AlarmDialog);
        label_3->setObjectName("label_3");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(label_3->sizePolicy().hasHeightForWidth());
        label_3->setSizePolicy(sizePolicy2);
        label_3->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(label_3, 2, 0, 1, 1);

        mTypeCombo = new QComboBox(AlarmDialog);
        mTypeCombo->addItem(QString());
        mTypeCombo->addItem(QString());
        mTypeCombo->setObjectName("mTypeCombo");
        sizePolicy1.setHeightForWidth(mTypeCombo->sizePolicy().hasHeightForWidth());
        mTypeCombo->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(mTypeCombo, 2, 1, 1, 1);

        mTypeStack = new QStackedWidget(AlarmDialog);
        mTypeStack->setObjectName("mTypeStack");
        DisplayStack = new QWidget();
        DisplayStack->setObjectName("DisplayStack");
        vboxLayout = new QVBoxLayout(DisplayStack);
        vboxLayout->setSpacing(6);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        mDisplayText = new KTextEdit(DisplayStack);
        mDisplayText->setObjectName("mDisplayText");
#if QT_CONFIG(tooltip)
        mDisplayText->setToolTip(QString::fromUtf8("Provide text to display when the reminder triggers"));
#endif // QT_CONFIG(tooltip)

        vboxLayout->addWidget(mDisplayText);

        mTypeStack->addWidget(DisplayStack);
        AudioStack = new QWidget();
        AudioStack->setObjectName("AudioStack");
        gridLayout_2 = new QGridLayout(AudioStack);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(0, 0, 0, 0);
        mSoundFileLabel = new QLabel(AudioStack);
        mSoundFileLabel->setObjectName("mSoundFileLabel");
        mSoundFileLabel->setAlignment(Qt::AlignJustify|Qt::AlignVCenter);

        gridLayout_2->addWidget(mSoundFileLabel, 0, 0, 1, 1);

        mSoundFile = new KUrlRequester(AudioStack);
        mSoundFile->setObjectName("mSoundFile");

        gridLayout_2->addWidget(mSoundFile, 0, 1, 1, 1);

        spacerItem = new QSpacerItem(20, 61, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(spacerItem, 1, 0, 1, 2);

        mTypeStack->addWidget(AudioStack);

        gridLayout->addWidget(mTypeStack, 3, 1, 1, 1);

#if QT_CONFIG(shortcut)
        mSoundFileLabel->setBuddy(mSoundFile);
#endif // QT_CONFIG(shortcut)

        retranslateUi(AlarmDialog);
        QObject::connect(mTypeCombo, &QComboBox::currentIndexChanged, mTypeStack, &QStackedWidget::setCurrentIndex);
        QObject::connect(mRepeats, &QCheckBox::clicked, mRepeatCount, &QSpinBox::setEnabled);
        QObject::connect(mRepeats, &QCheckBox::toggled, mRepeatInterval, &QSpinBox::setEnabled);

        mTypeStack->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(AlarmDialog);
    } // setupUi

    void retranslateUi(QWidget *AlarmDialog)
    {
        AlarmDialog->setWindowTitle(tr2i18n("Alarms", nullptr));
        label->setText(tr2i18n("When:", nullptr));
#if QT_CONFIG(tooltip)
        mAlarmOffset->setToolTip(tr2i18n("Set the reminder trigger time", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mAlarmOffset->setWhatsThis(tr2i18n("This spinbox allows you to set the reminder trigger time. The time unit is set in the combobox immediately adjacent.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mOffsetUnit->setItemText(0, tr2i18n("minute(s)", "@item:inlistbox alarm offset expressed in minutes"));
        mOffsetUnit->setItemText(1, tr2i18n("hour(s)", "@item:inlistbox alarm offset expressed in hours"));
        mOffsetUnit->setItemText(2, tr2i18n("day(s)", "@item:inlistbox alarm offset expressed in days"));

#if QT_CONFIG(tooltip)
        mOffsetUnit->setToolTip(tr2i18n("Select the reminder trigger time unit", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mOffsetUnit->setWhatsThis(tr2i18n("This combobox allows you to set the units for the reminder trigger time. The trigger time value is set in the spinbox immediately adjacent.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mBeforeAfter->setItemText(0, tr2i18n("before the event starts", nullptr));
        mBeforeAfter->setItemText(1, tr2i18n("after the event starts", nullptr));
        mBeforeAfter->setItemText(2, tr2i18n("before the event ends", nullptr));
        mBeforeAfter->setItemText(3, tr2i18n("after the event ends", nullptr));

#if QT_CONFIG(tooltip)
        mBeforeAfter->setToolTip(tr2i18n("Select the reminder trigger relative to the start or end time", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mBeforeAfter->setWhatsThis(tr2i18n("Use this combobox to specify if you want the reminder to trigger before or after the start or end time.", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_2->setText(tr2i18n("Repeat:", nullptr));
#if QT_CONFIG(tooltip)
        mRepeats->setToolTip(tr2i18n("Set the reminder to repeat", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mRepeats->setWhatsThis(tr2i18n("Check this if you want to the reminder to recur on a periodic interval.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mRepeats->setText(QString());
#if QT_CONFIG(tooltip)
        mRepeatCount->setToolTip(tr2i18n("Select how often the reminder should repeat", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mRepeatCount->setWhatsThis(tr2i18n("Use this selector to choose how many times you want the recurring reminder to repeat.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mRepeatCount->setSuffix(tr2i18n(" time(s)", nullptr));
#if QT_CONFIG(tooltip)
        mRepeatInterval->setToolTip(tr2i18n("Select the time between reminder repeats", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mRepeatInterval->setWhatsThis(tr2i18n("Use this selector to choose the time between repeating reminders.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mRepeatInterval->setSuffix(tr2i18n(" Minute(s)", "@label:spinbox repeat interval expressed in minutes"));
        mRepeatInterval->setPrefix(tr2i18n("every ", "repeat every X minutes"));
        label_3->setText(tr2i18n("What:", nullptr));
        mTypeCombo->setItemText(0, tr2i18n("Display text", nullptr));
        mTypeCombo->setItemText(1, tr2i18n("Play sound file", nullptr));

#if QT_CONFIG(tooltip)
        mTypeCombo->setToolTip(tr2i18n("Select the alarm type", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mTypeCombo->setWhatsThis(tr2i18n("Use this selector to choose the alarm type for the reminders.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        mDisplayText->setWhatsThis(tr2i18n("Specify any text you desire to display in the popup notice when the reminder triggers.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mSoundFileLabel->setText(tr2i18n("Audio File:", nullptr));
#if QT_CONFIG(tooltip)
        mSoundFile->setToolTip(tr2i18n("Specify a file containing a sound to play when the reminder triggers", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mSoundFile->setWhatsThis(tr2i18n("Use the adjacent file browser to help you find the file you want to use when playing a sound when the reminder triggers.", nullptr));
#endif // QT_CONFIG(whatsthis)
    } // retranslateUi

};

namespace Ui {
    class AlarmDialog: public Ui_AlarmDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ALARMDIALOG_H

