/********************************************************************************
** Form generated from reading UI file 'template_management_dialog_base.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TEMPLATE_MANAGEMENT_DIALOG_BASE_H
#define UI_TEMPLATE_MANAGEMENT_DIALOG_BASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_TemplateManagementDialog_base
{
public:
    QGridLayout *gridLayout;
    QLabel *m_introLabel;
    QListWidget *m_listBox;
    QVBoxLayout *verticalLayout_2;
    QVBoxLayout *verticalLayout;
    QPushButton *m_buttonAdd;
    QPushButton *m_buttonRemove;
    QPushButton *m_buttonApply;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *TemplateManagementDialog_base)
    {
        if (TemplateManagementDialog_base->objectName().isEmpty())
            TemplateManagementDialog_base->setObjectName("TemplateManagementDialog_base");
        TemplateManagementDialog_base->resize(664, 390);
        gridLayout = new QGridLayout(TemplateManagementDialog_base);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName("gridLayout");
        m_introLabel = new QLabel(TemplateManagementDialog_base);
        m_introLabel->setObjectName("m_introLabel");
        m_introLabel->setFrameShape(QFrame::NoFrame);
        m_introLabel->setWordWrap(true);

        gridLayout->addWidget(m_introLabel, 0, 0, 1, 2);

        m_listBox = new QListWidget(TemplateManagementDialog_base);
        m_listBox->setObjectName("m_listBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_listBox->sizePolicy().hasHeightForWidth());
        m_listBox->setSizePolicy(sizePolicy);

        gridLayout->addWidget(m_listBox, 1, 0, 1, 1);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        m_buttonAdd = new QPushButton(TemplateManagementDialog_base);
        m_buttonAdd->setObjectName("m_buttonAdd");

        verticalLayout->addWidget(m_buttonAdd);

        m_buttonRemove = new QPushButton(TemplateManagementDialog_base);
        m_buttonRemove->setObjectName("m_buttonRemove");
        m_buttonRemove->setEnabled(false);

        verticalLayout->addWidget(m_buttonRemove);

        m_buttonApply = new QPushButton(TemplateManagementDialog_base);
        m_buttonApply->setObjectName("m_buttonApply");

        verticalLayout->addWidget(m_buttonApply);


        verticalLayout_2->addLayout(verticalLayout);

        verticalSpacer = new QSpacerItem(20, 108, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);


        gridLayout->addLayout(verticalLayout_2, 1, 1, 1, 1);


        retranslateUi(TemplateManagementDialog_base);

        QMetaObject::connectSlotsByName(TemplateManagementDialog_base);
    } // setupUi

    void retranslateUi(QWidget *TemplateManagementDialog_base)
    {
        TemplateManagementDialog_base->setWindowTitle(tr2i18n("Template Management", nullptr));
        m_introLabel->setText(tr2i18n("Select a template and click <i>Apply</i> to apply it to this item. Click <i>New</i> to create a new template based on the current item settings.", "@label"));
#if QT_CONFIG(tooltip)
        m_listBox->setToolTip(tr2i18n("The list of managed templates", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        m_listBox->setWhatsThis(tr2i18n("This is a list of all the templates you have currently accessible for creating new calendar items.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        m_buttonAdd->setToolTip(tr2i18n("Create a new template from the current settings", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        m_buttonAdd->setWhatsThis(tr2i18n("Click on this button to create a new template based on the current settings in the editor. You can use this template to quickly add new items in the future.", nullptr));
#endif // QT_CONFIG(whatsthis)
        m_buttonAdd->setText(tr2i18n("&New\342\200\246", nullptr));
#if QT_CONFIG(tooltip)
        m_buttonRemove->setToolTip(tr2i18n("Remove the currently selected template", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        m_buttonRemove->setWhatsThis(tr2i18n("Clicking this button will permanently remove the selected template from your list of managed templates.", nullptr));
#endif // QT_CONFIG(whatsthis)
        m_buttonRemove->setText(tr2i18n("&Remove", nullptr));
#if QT_CONFIG(tooltip)
        m_buttonApply->setToolTip(tr2i18n("Apply the selected template settings", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        m_buttonApply->setWhatsThis(tr2i18n("Clicking this button will apply the settings from the selected template to the item you are currently editing.", nullptr));
#endif // QT_CONFIG(whatsthis)
        m_buttonApply->setText(tr2i18n("Apply", nullptr));
    } // retranslateUi

};

namespace Ui {
    class TemplateManagementDialog_base: public Ui_TemplateManagementDialog_base {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TEMPLATE_MANAGEMENT_DIALOG_BASE_H

