/********************************************************************************
** Form generated from reading UI file 'schedulingdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SCHEDULINGDIALOG_H
#define UI_SCHEDULINGDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTableView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "Libkdepim/KCheckComboBox"
#include "kdatecombobox.h"
#include "ktimecombobox.h"
#include "kweekdaycheckcombo.h"

QT_BEGIN_NAMESPACE

class Ui_Dialog
{
public:
    QGridLayout *gridLayout_2;
    QHBoxLayout *horizontalLayout_3;
    QFormLayout *formLayout;
    QLabel *label;
    QHBoxLayout *horizontalLayout;
    KDateComboBox *mStartDate;
    KTimeComboBox *mStartTime;
    QLabel *label_2;
    QHBoxLayout *horizontalLayout_2;
    KDateComboBox *mEndDate;
    KTimeComboBox *mEndTime;
    QFormLayout *formLayout_2;
    QLabel *label_3;
    IncidenceEditorNG::KWeekdayCheckCombo *mWeekdayCombo;
    QLabel *label_5;
    KPIM::KCheckComboBox *mRolesCombo;
    QTabWidget *mTabWidget;
    QWidget *mTextTab;
    QGridLayout *gridLayout;
    QTableView *mTableView;
    QWidget *mGanttTab;
    QGroupBox *mMoveApptGroupBox;
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout_4;
    QSpacerItem *horizontalSpacer;
    QLabel *mMoveDayLabel;
    KTimeComboBox *mMoveBeginTimeEdit;
    QLabel *mMoveEndTimeLabel;
    QSpacerItem *horizontalSpacer_2;

    void setupUi(QWidget *Dialog)
    {
        if (Dialog->objectName().isEmpty())
            Dialog->setObjectName("Dialog");
        Dialog->resize(558, 502);
        gridLayout_2 = new QGridLayout(Dialog);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        label = new QLabel(Dialog);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        mStartDate = new KDateComboBox(Dialog);
        mStartDate->setObjectName("mStartDate");

        horizontalLayout->addWidget(mStartDate);

        mStartTime = new KTimeComboBox(Dialog);
        mStartTime->setObjectName("mStartTime");

        horizontalLayout->addWidget(mStartTime);


        formLayout->setLayout(0, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        label_2 = new QLabel(Dialog);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        mEndDate = new KDateComboBox(Dialog);
        mEndDate->setObjectName("mEndDate");

        horizontalLayout_2->addWidget(mEndDate);

        mEndTime = new KTimeComboBox(Dialog);
        mEndTime->setObjectName("mEndTime");

        horizontalLayout_2->addWidget(mEndTime);


        formLayout->setLayout(1, QFormLayout::ItemRole::FieldRole, horizontalLayout_2);


        horizontalLayout_3->addLayout(formLayout);

        formLayout_2 = new QFormLayout();
        formLayout_2->setObjectName("formLayout_2");
        label_3 = new QLabel(Dialog);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, label_3);

        mWeekdayCombo = new IncidenceEditorNG::KWeekdayCheckCombo(Dialog);
        mWeekdayCombo->setObjectName("mWeekdayCombo");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(mWeekdayCombo->sizePolicy().hasHeightForWidth());
        mWeekdayCombo->setSizePolicy(sizePolicy);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, mWeekdayCombo);

        label_5 = new QLabel(Dialog);
        label_5->setObjectName("label_5");
        label_5->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, label_5);

        mRolesCombo = new KPIM::KCheckComboBox(Dialog);
        mRolesCombo->setObjectName("mRolesCombo");
        sizePolicy.setHeightForWidth(mRolesCombo->sizePolicy().hasHeightForWidth());
        mRolesCombo->setSizePolicy(sizePolicy);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, mRolesCombo);


        horizontalLayout_3->addLayout(formLayout_2);


        gridLayout_2->addLayout(horizontalLayout_3, 0, 0, 1, 1);

        mTabWidget = new QTabWidget(Dialog);
        mTabWidget->setObjectName("mTabWidget");
        mTextTab = new QWidget();
        mTextTab->setObjectName("mTextTab");
        gridLayout = new QGridLayout(mTextTab);
        gridLayout->setObjectName("gridLayout");
        mTableView = new QTableView(mTextTab);
        mTableView->setObjectName("mTableView");
        mTableView->setAlternatingRowColors(true);
        mTableView->setSelectionMode(QAbstractItemView::SingleSelection);
        mTableView->setSelectionBehavior(QAbstractItemView::SelectRows);
        mTableView->setShowGrid(false);
        mTableView->horizontalHeader()->setVisible(false);
        mTableView->horizontalHeader()->setStretchLastSection(true);
        mTableView->verticalHeader()->setVisible(false);
        mTableView->verticalHeader()->setStretchLastSection(false);

        gridLayout->addWidget(mTableView, 0, 0, 1, 1);

        mTabWidget->addTab(mTextTab, QString());
        mGanttTab = new QWidget();
        mGanttTab->setObjectName("mGanttTab");
        mTabWidget->addTab(mGanttTab, QString());

        gridLayout_2->addWidget(mTabWidget, 1, 0, 1, 1);

        mMoveApptGroupBox = new QGroupBox(Dialog);
        mMoveApptGroupBox->setObjectName("mMoveApptGroupBox");
        verticalLayout_3 = new QVBoxLayout(mMoveApptGroupBox);
        verticalLayout_3->setObjectName("verticalLayout_3");
        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer);

        mMoveDayLabel = new QLabel(mMoveApptGroupBox);
        mMoveDayLabel->setObjectName("mMoveDayLabel");
        mMoveDayLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_4->addWidget(mMoveDayLabel);

        mMoveBeginTimeEdit = new KTimeComboBox(mMoveApptGroupBox);
        mMoveBeginTimeEdit->setObjectName("mMoveBeginTimeEdit");

        horizontalLayout_4->addWidget(mMoveBeginTimeEdit);

        mMoveEndTimeLabel = new QLabel(mMoveApptGroupBox);
        mMoveEndTimeLabel->setObjectName("mMoveEndTimeLabel");

        horizontalLayout_4->addWidget(mMoveEndTimeLabel);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_2);


        verticalLayout_3->addLayout(horizontalLayout_4);


        gridLayout_2->addWidget(mMoveApptGroupBox, 2, 0, 1, 1);


        retranslateUi(Dialog);

        mTabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(Dialog);
    } // setupUi

    void retranslateUi(QWidget *Dialog)
    {
        Dialog->setWindowTitle(tr2i18n("Schedule a time", nullptr));
        label->setText(tr2i18n("Earliest time to start:", nullptr));
        label_2->setText(tr2i18n("Latest time to end:", nullptr));
#if QT_CONFIG(tooltip)
        label_3->setToolTip(tr2i18n("Check the weekdays to include in the search.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(statustip)
        label_3->setStatusTip(QString());
#endif // QT_CONFIG(statustip)
#if QT_CONFIG(whatsthis)
        label_3->setWhatsThis(tr2i18n("Only the checked weekdays will be included in the free time slot search.", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_3->setText(tr2i18n("Allowed weekdays:", nullptr));
#if QT_CONFIG(tooltip)
        mWeekdayCombo->setToolTip(tr2i18n("Check the weekdays to include in the search.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mWeekdayCombo->setWhatsThis(tr2i18n("Only the checked weekdays will be included in the free time slot search.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        label_5->setToolTip(tr2i18n("Check the roles to include in the search.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        label_5->setWhatsThis(tr2i18n("Only the participants with the checked roles will be considered in the free time slot search.", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_5->setText(tr2i18n("Mandatory roles:", nullptr));
#if QT_CONFIG(tooltip)
        mRolesCombo->setToolTip(tr2i18n("Check the roles to include in the search.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mRolesCombo->setWhatsThis(tr2i18n("Only the participants with the checked roles will be considered in the free time slot search.", nullptr));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(tooltip)
        mTabWidget->setToolTip(tr2i18n("Select the search option", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        mTabWidget->setWhatsThis(tr2i18n("Use these tabs to choose the search option.", nullptr));
#endif // QT_CONFIG(whatsthis)
        mTabWidget->setTabText(mTabWidget->indexOf(mTextTab), tr2i18n("Automatic Search", nullptr));
        mTabWidget->setTabText(mTabWidget->indexOf(mGanttTab), tr2i18n("Visual Search", nullptr));
        mMoveApptGroupBox->setTitle(tr2i18n("Move your appointment to:", nullptr));
        mMoveDayLabel->setText(tr2i18n("Monday, 12th June", nullptr));
        mMoveEndTimeLabel->setText(tr2i18n("to 10:00am", nullptr));
    } // retranslateUi

};

namespace Ui {
    class Dialog: public Ui_Dialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SCHEDULINGDIALOG_H

