/****************************************************************************
** Meta object code from reading C++ file 'conflictresolver.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../incidenceeditor-26.04.2/src/conflictresolver.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'conflictresolver.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17IncidenceEditorNG16ConflictResolverE_t {};
} // unnamed namespace

template <> constexpr inline auto IncidenceEditorNG::ConflictResolver::qt_create_metaobjectdata<qt_meta_tag_ZN17IncidenceEditorNG16ConflictResolverE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "IncidenceEditorNG::ConflictResolver",
        "dateTimesChanged",
        "",
        "newStart",
        "newEnd",
        "conflictsDetected",
        "number",
        "freeSlotsAvailable",
        "KCalendarCore::Period::List",
        "setEarliestDate",
        "newDate",
        "setEarliestTime",
        "newTime",
        "setLatestDate",
        "setLatestTime",
        "setEarliestDateTime",
        "newDateTime",
        "setLatestDateTime",
        "freebusyDataChanged",
        "findAllFreeSlots",
        "setResolution",
        "seconds"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'dateTimesChanged'
        QtMocHelpers::SignalData<void(const QDateTime &, const QDateTime &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDateTime, 3 }, { QMetaType::QDateTime, 4 },
        }}),
        // Signal 'conflictsDetected'
        QtMocHelpers::SignalData<void(int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Signal 'freeSlotsAvailable'
        QtMocHelpers::SignalData<void(const KCalendarCore::Period::List &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Slot 'setEarliestDate'
        QtMocHelpers::SlotData<void(QDate)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 10 },
        }}),
        // Slot 'setEarliestTime'
        QtMocHelpers::SlotData<void(QTime)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QTime, 12 },
        }}),
        // Slot 'setLatestDate'
        QtMocHelpers::SlotData<void(QDate)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 10 },
        }}),
        // Slot 'setLatestTime'
        QtMocHelpers::SlotData<void(QTime)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QTime, 12 },
        }}),
        // Slot 'setEarliestDateTime'
        QtMocHelpers::SlotData<void(const QDateTime &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDateTime, 16 },
        }}),
        // Slot 'setLatestDateTime'
        QtMocHelpers::SlotData<void(const QDateTime &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDateTime, 16 },
        }}),
        // Slot 'freebusyDataChanged'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'findAllFreeSlots'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setResolution'
        QtMocHelpers::SlotData<void(int)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ConflictResolver, qt_meta_tag_ZN17IncidenceEditorNG16ConflictResolverE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject IncidenceEditorNG::ConflictResolver::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17IncidenceEditorNG16ConflictResolverE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17IncidenceEditorNG16ConflictResolverE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17IncidenceEditorNG16ConflictResolverE_t>.metaTypes,
    nullptr
} };

void IncidenceEditorNG::ConflictResolver::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ConflictResolver *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->dateTimesChanged((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[2]))); break;
        case 1: _t->conflictsDetected((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->freeSlotsAvailable((*reinterpret_cast<std::add_pointer_t<KCalendarCore::Period::List>>(_a[1]))); break;
        case 3: _t->setEarliestDate((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 4: _t->setEarliestTime((*reinterpret_cast<std::add_pointer_t<QTime>>(_a[1]))); break;
        case 5: _t->setLatestDate((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 6: _t->setLatestTime((*reinterpret_cast<std::add_pointer_t<QTime>>(_a[1]))); break;
        case 7: _t->setEarliestDateTime((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1]))); break;
        case 8: _t->setLatestDateTime((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1]))); break;
        case 9: _t->freebusyDataChanged(); break;
        case 10: _t->findAllFreeSlots(); break;
        case 11: _t->setResolution((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ConflictResolver::*)(const QDateTime & , const QDateTime & )>(_a, &ConflictResolver::dateTimesChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConflictResolver::*)(int )>(_a, &ConflictResolver::conflictsDetected, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ConflictResolver::*)(const KCalendarCore::Period::List & )>(_a, &ConflictResolver::freeSlotsAvailable, 2))
            return;
    }
}

const QMetaObject *IncidenceEditorNG::ConflictResolver::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *IncidenceEditorNG::ConflictResolver::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17IncidenceEditorNG16ConflictResolverE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int IncidenceEditorNG::ConflictResolver::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void IncidenceEditorNG::ConflictResolver::dateTimesChanged(const QDateTime & _t1, const QDateTime & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void IncidenceEditorNG::ConflictResolver::conflictsDetected(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void IncidenceEditorNG::ConflictResolver::freeSlotsAvailable(const KCalendarCore::Period::List & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
