/****************************************************************************
** Meta object code from reading C++ file 'incidencedatetime.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../incidenceeditor-26.04.2/src/incidencedatetime.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'incidencedatetime.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17IncidenceEditorNG17IncidenceDateTimeE_t {};
} // unnamed namespace

template <> constexpr inline auto IncidenceEditorNG::IncidenceDateTime::qt_create_metaobjectdata<qt_meta_tag_ZN17IncidenceEditorNG17IncidenceDateTimeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "IncidenceEditorNG::IncidenceDateTime",
        "startDateFocus",
        "",
        "obj",
        "endDateFocus",
        "startTimeFocus",
        "endTimeFocus",
        "startDateTimeToggled",
        "enabled",
        "startDateChanged",
        "newDate",
        "startTimeChanged",
        "newTime",
        "endDateTimeToggled",
        "endDateChanged",
        "endTimeChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'startDateFocus'
        QtMocHelpers::SignalData<void(QObject *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 3 },
        }}),
        // Signal 'endDateFocus'
        QtMocHelpers::SignalData<void(QObject *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 3 },
        }}),
        // Signal 'startTimeFocus'
        QtMocHelpers::SignalData<void(QObject *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 3 },
        }}),
        // Signal 'endTimeFocus'
        QtMocHelpers::SignalData<void(QObject *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 3 },
        }}),
        // Signal 'startDateTimeToggled'
        QtMocHelpers::SignalData<void(bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Signal 'startDateChanged'
        QtMocHelpers::SignalData<void(const QDate &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 10 },
        }}),
        // Signal 'startTimeChanged'
        QtMocHelpers::SignalData<void(const QTime &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QTime, 12 },
        }}),
        // Signal 'endDateTimeToggled'
        QtMocHelpers::SignalData<void(bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Signal 'endDateChanged'
        QtMocHelpers::SignalData<void(const QDate &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 10 },
        }}),
        // Signal 'endTimeChanged'
        QtMocHelpers::SignalData<void(const QTime &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QTime, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<IncidenceDateTime, qt_meta_tag_ZN17IncidenceEditorNG17IncidenceDateTimeE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject IncidenceEditorNG::IncidenceDateTime::staticMetaObject = { {
    QMetaObject::SuperData::link<IncidenceEditor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17IncidenceEditorNG17IncidenceDateTimeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17IncidenceEditorNG17IncidenceDateTimeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17IncidenceEditorNG17IncidenceDateTimeE_t>.metaTypes,
    nullptr
} };

void IncidenceEditorNG::IncidenceDateTime::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<IncidenceDateTime *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->startDateFocus((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 1: _t->endDateFocus((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 2: _t->startTimeFocus((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 3: _t->endTimeFocus((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 4: _t->startDateTimeToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->startDateChanged((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 6: _t->startTimeChanged((*reinterpret_cast<std::add_pointer_t<QTime>>(_a[1]))); break;
        case 7: _t->endDateTimeToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->endDateChanged((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1]))); break;
        case 9: _t->endTimeChanged((*reinterpret_cast<std::add_pointer_t<QTime>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (IncidenceDateTime::*)(QObject * )>(_a, &IncidenceDateTime::startDateFocus, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceDateTime::*)(QObject * )>(_a, &IncidenceDateTime::endDateFocus, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceDateTime::*)(QObject * )>(_a, &IncidenceDateTime::startTimeFocus, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceDateTime::*)(QObject * )>(_a, &IncidenceDateTime::endTimeFocus, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceDateTime::*)(bool )>(_a, &IncidenceDateTime::startDateTimeToggled, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceDateTime::*)(const QDate & )>(_a, &IncidenceDateTime::startDateChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceDateTime::*)(const QTime & )>(_a, &IncidenceDateTime::startTimeChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceDateTime::*)(bool )>(_a, &IncidenceDateTime::endDateTimeToggled, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceDateTime::*)(const QDate & )>(_a, &IncidenceDateTime::endDateChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceDateTime::*)(const QTime & )>(_a, &IncidenceDateTime::endTimeChanged, 9))
            return;
    }
}

const QMetaObject *IncidenceEditorNG::IncidenceDateTime::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *IncidenceEditorNG::IncidenceDateTime::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17IncidenceEditorNG17IncidenceDateTimeE_t>.strings))
        return static_cast<void*>(this);
    return IncidenceEditor::qt_metacast(_clname);
}

int IncidenceEditorNG::IncidenceDateTime::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = IncidenceEditor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void IncidenceEditorNG::IncidenceDateTime::startDateFocus(QObject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void IncidenceEditorNG::IncidenceDateTime::endDateFocus(QObject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void IncidenceEditorNG::IncidenceDateTime::startTimeFocus(QObject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void IncidenceEditorNG::IncidenceDateTime::endTimeFocus(QObject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void IncidenceEditorNG::IncidenceDateTime::startDateTimeToggled(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void IncidenceEditorNG::IncidenceDateTime::startDateChanged(const QDate & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void IncidenceEditorNG::IncidenceDateTime::startTimeChanged(const QTime & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void IncidenceEditorNG::IncidenceDateTime::endDateTimeToggled(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void IncidenceEditorNG::IncidenceDateTime::endDateChanged(const QDate & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void IncidenceEditorNG::IncidenceDateTime::endTimeChanged(const QTime & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}
QT_WARNING_POP
