/****************************************************************************
** Meta object code from reading C++ file 'individualmailcomponentfactory.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../incidenceeditor-26.04.2/src/individualmailcomponentfactory.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'individualmailcomponentfactory.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17IncidenceEditorNG25IndividualMessageQueueJobE_t {};
} // unnamed namespace

template <> constexpr inline auto IncidenceEditorNG::IndividualMessageQueueJob::qt_create_metaobjectdata<qt_meta_tag_ZN17IncidenceEditorNG25IndividualMessageQueueJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "IncidenceEditorNG::IndividualMessageQueueJob"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<IndividualMessageQueueJob, qt_meta_tag_ZN17IncidenceEditorNG25IndividualMessageQueueJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject IncidenceEditorNG::IndividualMessageQueueJob::staticMetaObject = { {
    QMetaObject::SuperData::link<Akonadi::MessageQueueJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17IncidenceEditorNG25IndividualMessageQueueJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17IncidenceEditorNG25IndividualMessageQueueJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17IncidenceEditorNG25IndividualMessageQueueJobE_t>.metaTypes,
    nullptr
} };

void IncidenceEditorNG::IndividualMessageQueueJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<IndividualMessageQueueJob *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *IncidenceEditorNG::IndividualMessageQueueJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *IncidenceEditorNG::IndividualMessageQueueJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17IncidenceEditorNG25IndividualMessageQueueJobE_t>.strings))
        return static_cast<void*>(this);
    return Akonadi::MessageQueueJob::qt_metacast(_clname);
}

int IncidenceEditorNG::IndividualMessageQueueJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Akonadi::MessageQueueJob::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN17IncidenceEditorNG39IndividualMailITIPHandlerDialogDelegateE_t {};
} // unnamed namespace

template <> constexpr inline auto IncidenceEditorNG::IndividualMailITIPHandlerDialogDelegate::qt_create_metaobjectdata<qt_meta_tag_ZN17IncidenceEditorNG39IndividualMailITIPHandlerDialogDelegateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "IncidenceEditorNG::IndividualMailITIPHandlerDialogDelegate",
        "setEdit",
        "",
        "KCalendarCore::Incidence::Ptr",
        "incidence",
        "KCalendarCore::Attendee::List",
        "edit",
        "setUpdate",
        "update"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'setEdit'
        QtMocHelpers::SignalData<void(const KCalendarCore::Incidence::Ptr &, const KCalendarCore::Attendee::List &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'setUpdate'
        QtMocHelpers::SignalData<void(const KCalendarCore::Incidence::Ptr &, const KCalendarCore::Attendee::List &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<IndividualMailITIPHandlerDialogDelegate, qt_meta_tag_ZN17IncidenceEditorNG39IndividualMailITIPHandlerDialogDelegateE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject IncidenceEditorNG::IndividualMailITIPHandlerDialogDelegate::staticMetaObject = { {
    QMetaObject::SuperData::link<Akonadi::ITIPHandlerDialogDelegate::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17IncidenceEditorNG39IndividualMailITIPHandlerDialogDelegateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17IncidenceEditorNG39IndividualMailITIPHandlerDialogDelegateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17IncidenceEditorNG39IndividualMailITIPHandlerDialogDelegateE_t>.metaTypes,
    nullptr
} };

void IncidenceEditorNG::IndividualMailITIPHandlerDialogDelegate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<IndividualMailITIPHandlerDialogDelegate *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->setEdit((*reinterpret_cast<std::add_pointer_t<KCalendarCore::Incidence::Ptr>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KCalendarCore::Attendee::List>>(_a[2]))); break;
        case 1: _t->setUpdate((*reinterpret_cast<std::add_pointer_t<KCalendarCore::Incidence::Ptr>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KCalendarCore::Attendee::List>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (IndividualMailITIPHandlerDialogDelegate::*)(const KCalendarCore::Incidence::Ptr & , const KCalendarCore::Attendee::List & )>(_a, &IndividualMailITIPHandlerDialogDelegate::setEdit, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (IndividualMailITIPHandlerDialogDelegate::*)(const KCalendarCore::Incidence::Ptr & , const KCalendarCore::Attendee::List & )>(_a, &IndividualMailITIPHandlerDialogDelegate::setUpdate, 1))
            return;
    }
}

const QMetaObject *IncidenceEditorNG::IndividualMailITIPHandlerDialogDelegate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *IncidenceEditorNG::IndividualMailITIPHandlerDialogDelegate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17IncidenceEditorNG39IndividualMailITIPHandlerDialogDelegateE_t>.strings))
        return static_cast<void*>(this);
    return Akonadi::ITIPHandlerDialogDelegate::qt_metacast(_clname);
}

int IncidenceEditorNG::IndividualMailITIPHandlerDialogDelegate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Akonadi::ITIPHandlerDialogDelegate::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void IncidenceEditorNG::IndividualMailITIPHandlerDialogDelegate::setEdit(const KCalendarCore::Incidence::Ptr & _t1, const KCalendarCore::Attendee::List & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void IncidenceEditorNG::IndividualMailITIPHandlerDialogDelegate::setUpdate(const KCalendarCore::Incidence::Ptr & _t1, const KCalendarCore::Attendee::List & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
namespace {
struct qt_meta_tag_ZN17IncidenceEditorNG30IndividualMailComponentFactoryE_t {};
} // unnamed namespace

template <> constexpr inline auto IncidenceEditorNG::IndividualMailComponentFactory::qt_create_metaobjectdata<qt_meta_tag_ZN17IncidenceEditorNG30IndividualMailComponentFactoryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "IncidenceEditorNG::IndividualMailComponentFactory",
        "onSetEdit",
        "",
        "KCalendarCore::Incidence::Ptr",
        "incidence",
        "KCalendarCore::Attendee::List",
        "edit",
        "onSetUpdate",
        "update"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'onSetEdit'
        QtMocHelpers::SlotData<void(const KCalendarCore::Incidence::Ptr &, const KCalendarCore::Attendee::List &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Slot 'onSetUpdate'
        QtMocHelpers::SlotData<void(const KCalendarCore::Incidence::Ptr &, const KCalendarCore::Attendee::List &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<IndividualMailComponentFactory, qt_meta_tag_ZN17IncidenceEditorNG30IndividualMailComponentFactoryE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject IncidenceEditorNG::IndividualMailComponentFactory::staticMetaObject = { {
    QMetaObject::SuperData::link<Akonadi::ITIPHandlerComponentFactory::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17IncidenceEditorNG30IndividualMailComponentFactoryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17IncidenceEditorNG30IndividualMailComponentFactoryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17IncidenceEditorNG30IndividualMailComponentFactoryE_t>.metaTypes,
    nullptr
} };

void IncidenceEditorNG::IndividualMailComponentFactory::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<IndividualMailComponentFactory *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->onSetEdit((*reinterpret_cast<std::add_pointer_t<KCalendarCore::Incidence::Ptr>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KCalendarCore::Attendee::List>>(_a[2]))); break;
        case 1: _t->onSetUpdate((*reinterpret_cast<std::add_pointer_t<KCalendarCore::Incidence::Ptr>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KCalendarCore::Attendee::List>>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject *IncidenceEditorNG::IndividualMailComponentFactory::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *IncidenceEditorNG::IndividualMailComponentFactory::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17IncidenceEditorNG30IndividualMailComponentFactoryE_t>.strings))
        return static_cast<void*>(this);
    return Akonadi::ITIPHandlerComponentFactory::qt_metacast(_clname);
}

int IncidenceEditorNG::IndividualMailComponentFactory::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Akonadi::ITIPHandlerComponentFactory::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}
QT_WARNING_POP
